<?php
namespace Teknisa\SM\Controller;

use Teknisa\SM\Controller\SMCrud;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Message;
use Teknisa\SM\Service\Sm00006000ElementoService as ElementoService;
use Teknisa\Libs\Util\NewCode;

class Sm00006000ElementoController extends SMCrud {
    protected $dataSourceName = "fct_servicoorca_tela_elemento";
    protected $elementoService;
    protected $newCode;
    
    public function __construct($crudService, $environment, ElementoService $elementoService, NewCode $newCode) {
        parent::__construct($crudService, $environment);
        $this->newCode = $newCode;
        $this->elementoService = $elementoService;
    }
    
    public function find(Request\Filter $request, Response $response) {
        try {
            $hasTagFilter = false;
            foreach($request->getFilterCriteria()->getConditions() as $filter) {
                if ($filter['columnName'] === 'CDSERVORCARELAC') {
                    $hasTagFilter = true;
                    break;
                }
            }
            if ($hasTagFilter) {
                $this->dataSourceName = "fct_servicoorca_tela_elemento_filtro_servrelac";
            }
            
            parent::find($request, $response);
            $erro = $response->getError();
            if ($erro) {
                throw new \Exception($erro->getMessage(), $erro->getErrorCode());
            }
            
            $this->dataSourceName = "fct_servicoorca_tela_elemento";
            
            //$response->setDataSets(array(new DataSet("fct_servicoorca_tela_elemento", $response->getDataSets()[0]->getRows)));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Salva o elemento.
     * 
     * @param Request $request
     * @param Response $response
     */
    public function save(Request $request, Response $response) {
        try {
            $rows = $request->getDataSet()->getRows();
            $nrorg = $this->environment->getNrOrg();
            
            foreach ($rows as &$row) {
                if ($row["__is_new"]) {
                    $codigo = $this->newCode->getCodeByTableName("FCT_SERVICOORCA", $nrorg, 1, 10, true);
                    $row["IDELEMENTO"] = $row["IDTIPOELEMENTO"] . "_" . $codigo;
                    $row["CDSERVORCA"] = $codigo;
                }
                else {
                    $this->elementoService->salvarMedidaVariavelEmCascata($row["CDTPMEDIDAVARIAVEL"], $row["IDELEMENTO"], $row["NRORG"]);
                }
            }
            unset($row);
            
            parent::save($request, $response);
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * Exclui o elemento e seus filhos.
     * 
     * @param Request $request
     * @param Response $response
     */
    public function delete(Request $request, Response $response) {
        try {
            $row = $request->getRow();
            $idelemento = $row["IDELEMENTO"];
            $nrorg      = $row["NRORG"];
            
            $this->elementoService->excluirElementoEmCascata($idelemento, $nrorg);
            $response->addMessage(new Message("Registro excluído com sucesso."));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
      /**
     *  A função "validaIdentificador"  Realiza a validação  do campo "identificador". 
     *  Não podem haver dois identificadores iguais.
     * @param Request $request
     * @param Response $response
     */
    public function validaIdentificador(Request $request, Response $response) {
        try {
            $row = $request->getRow();
            $idItemCalculo = $row["IDITEMCALCULO"];
            
            $identificador = $this->elementoService->validaIdentificador($idItemCalculo);
            
            $dtsIdentificador = new DataSet('IDENTIFICADOR', $identificador);
        
            $response->addDataSet($dtsIdentificador);
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function updateNomeOm(Request $request, Response $response) {
        try {
            $row = $request->getRow();
            $idElemento = $row["IDELEMENTO"];
            $nmServOrca = $row["NMSERVORCA"];
            
            $this->elementoService->updateNomeOm($idElemento, $nmServOrca);
            
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
}

?>