<?php

namespace Teknisa\SM\Factory;

use Doctrine\ORM\EntityManager;

class Sm00004000ContratoFactory {
    
    protected $connection;
    
    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }
    
    /**
     * Busca os contratos que foram gerados pelas propostas informadas.
     * 
     * @param string $nrseqorcamento
     * @param number $nrorg
     */
    public function getContratosDasPropostas($nrseqorcamento, $nrorg) {
        $sql = "SELECT NRSEQCONTRATO
                  FROM FCT_REFEORCACONT
                 WHERE NRSEQORCAMENTO IN (".$nrseqorcamento.")
                   AND NRORG          = :NRORG";
        
        $params = array("NRORG" => $nrorg);
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Verifica se algum dos contratos informados está aprovado.
     * 
     * @param string $nrseqcontrato
     * @param number $nrorg
     */
    public function existeContratoDiferentesP($nrseqcontrato, $nrorg) {
        $sql = "SELECT COUNT(*) AS EXISTE, 
                       MAX(NRVERSAOCONTRATO) AS VERSAO
                FROM FCT_CONTRATO
                WHERE NRORG  = :NRORG
                    AND IDATIVO = 'S'
                    AND IDSITUACAOCONTRATO <> 'P'
                GROUP BY NRSEQCONTRATO
                CONNECT BY PRIOR NRSEQCONTRATO = NRSEQCONTRATOPAI
                    START WITH NRSEQCONTRATO IN (SELECT NRSEQCONTRATO 
                                             FROM FCT_CONTRATO
                                             WHERE NRSEQCONTRATO IN({$nrseqcontrato})
                                                AND NRORG = :NRORG
                                                AND NRSEQCONTRATOPAI IS NULL)";
        $params = array("NRORG" => $nrorg);
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Exclui os contratos informados.
     * 
     * @param string $nrseqcontrato
     * @param number $nrorg
     */
    public function reprovarContratos($nrseqcontrato, $nrorg) {
        $sql = "UPDATE FCT_CONTRATO
                 SET IDSITUACAOCONTRATO = 'R'
                 WHERE NRSEQCONTRATO IN (".$nrseqcontrato.")
                   AND NRORG         = :NRORG";

        $params = array("NRORG" => $nrorg);
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * A função "recebeParamFatModCont" recebe os dados de Faturamento do Modelo de Contrato
     */

    public function recebeParamFatModCont($params){
        
        $sql = "SELECT NRGRUPOFATURA, IDSOMAFATUCONT, IDSOMAITGRUPFAT, IDGERANFPARC, IDBLOQSEMMEDIC, 
                       IDBLOQVRMEDIC, IDGERARATEIO
                  FROM FCT_PARAMFATMODCONT
                 WHERE NRSEQMODCONTRA = :NRSEQMODCONTRA
                   AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $returnParamFatModCont = $std->fetchAll();
        return $returnParamFatModCont;
    }
    
    /**
     * A função "recebeModReajustContr" recebe os dados de Reajuste do Modelo de Contrato
     */
    
    public function recebeModReajustContr($params){
        
        $sql = "SELECT NRSEQMODREAJUS, NMMODREAJUSCONTR, IDTPREAJUSTE, IDTPMESREAJUSTE, NRQTDREAJUSTE  
                  FROM FCT_MODREAJUSTCONTR 
                 WHERE NRSEQMODCONTRA = :NRSEQMODCONTRA
                   AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $returnModReajustContr = $std->fetchAll();
        return $returnModReajustContr;
    }
    
    /**
     * A função "recebeModIndContr" recebe os dados de Indice de Reajuste do Modelo de Contrato
     */
     
    public function recebeModIndContr($params){
        
        $sql = "SELECT CDTPINDICE, IDPERVALOR, CDINDICE, VRPERCINDCONTR
                  FROM FCT_MODINDCONTR 
                 WHERE NRSEQMODCONTRA = :NRSEQMODCONTRA
                   AND NRSEQMODREAJUS = :NRSEQMODREAJUS
                   AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $returnModIndContr = $std->fetchAll();
        return $returnModIndContr;
    }
    
    /**
     * A função "recebeModeloDocContr" recebe os dados de Documento do Modelo de Contrato
     */
    
    public function recebeModeloDocContr($params){
        $sql = "SELECT MODCONT.NRSEQMODDOCFCT,
                       MODCONT.IDMODPADRAO,
                       DOC.NMARQUIVO,
                       DOC.DSCAMINHOARQ,
                       DOC.VRTAMANHO,
                       DOC.DSTIPO,
                       MODCONT.IDSITUACAOCONTRATO,
                       DOC.VRTAMANHOLOGO
                  FROM FCT_MODELODOCCONTR MODCONT
                 INNER JOIN FCT_MODELODOC DOC
                    ON MODCONT.NRSEQMODDOCFCT = DOC.NRSEQMODDOCFCT
                   AND MODCONT.NRORG          = DOC.NRORG
                 WHERE MODCONT.NRSEQMODCONTRA = :NRSEQMODCONTRA
                   AND MODCONT.NRORG          = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $returnModeloDocContr = $std->fetchAll();
        return $returnModeloDocContr;
    }
    
    public function getDocumentosContratosGerados(array $params) {
        $sql = "SELECT DOC.NRSEQCONTRATO,
                       DOC.NRSEQCONTDOC,
                       DOC.NMARQUIVO,
                       DOC.DSCAMINHOARQ,
                       DOC.DSTIPO,
                       DOC.VRTAMANHO,
                       DOC.IDSITUACAOCONTRATO
                  FROM FCT_CONTRATODOC DOC
                 WHERE DOC.NRSEQCONTRATO = :NRSEQCONTRATO
                   AND DOC.NRORG         = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function atualizarCaminhoDocumentoContrato(array $params) {
        $sql = "UPDATE FCT_CONTRATODOC
                   SET DSCAMINHOARQ = :DSCAMINHOARQ
                 WHERE NRSEQCONTDOC  = :NRSEQCONTDOC
                   AND NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG         = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function atualizarCaminhoDocumentoGeradoPDFContrato(array $params) {
        $sql = "UPDATE FCT_CONTRATODOC
                   SET DSCAMINHODOCGERADOPDF = :DSCAMINHODOCGERADOPDF
                 WHERE NRSEQCONTDOC          = :NRSEQCONTDOC
                   AND NRORG                 = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function getCaminhoDocumentoGeradoPDFContrato(array $params) {
        $sql = "SELECT DSCAMINHODOCGERADOPDF
                  FROM FCT_CONTRATODOC
                 WHERE NRSEQCONTDOC = :NRSEQCONTDOC
                   AND NRORG        = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();

    }

    /**
     * Deleta da tabela de agendamentos pendentes os items deletados no 
     * contrato aprovado
     */
    public function DeletaAgendPendenteContratoEncerrado(array $params){
        $sql = "DELETE FROM FCT_AGENDPENDENTE
                WHERE NRSEQCONTRATO     = :NRSEQCONTRATO
                    AND NRORG           = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * Deleta da tabela FCT_CONTRATODOC
     * os documentos referentes aos contratos que serão excluídos
    **/
    public function deletaDocumentosContrato($nrseqcontrato, array $params){
        $sql = "DELETE FROM FCT_CONTRATODOC
                WHERE NRSEQCONTRATO IN(".$nrseqcontrato.")
                    AND NRORG = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * Retorna o parametro validação para a geração de 
     * documentos em pdf
    **/
    public function getParametroExtensaoDoc(array $params){
        $sql = "SELECT IDPERMITEDOCX
                FROM FCT_CONTRATO CONT
                LEFT JOIN FCT_MODELOCONTRATO MODELO
                    ON CONT.NRSEQMODCONTRA     = MODELO.NRSEQMODCONTRA
                    AND CONT.NRORG             = MODELO.NRORG
                LEFT JOIN FCT_MODELODOCCONTR CONTDOC
                    ON MODELO.NRSEQMODCONTRA = CONTDOC.NRSEQMODCONTRA
                    AND MODELO.NRORG         = CONTDOC.NRORG
                WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                    AND CONT.NRORG     = :NRORG";
                    
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
     
     /* Retorna a proposta que gerou o contrato.
     */
    public function getPropostaDoContrato(array $params) {
        $sql = "SELECT ORC.NRSEQORCAMENTO,
                       ORC.NRORCAMENTOMODELO,
                       NVL(REF.NRTIPOORCAMENTO, ORC.NRTIPOORCAMENTO) AS NRTIPOORCAMENTO
                  FROM FCT_REFEORCACONT REF
                 INNER JOIN FCT_ORCAMENTO ORC
                    ON REF.NRSEQORCAMENTO = ORC.NRSEQORCAMENTO
                   AND REF.NRORG          = ORC.NRORG
                 WHERE REF.NRSEQCONTRATO = :NRSEQCONTRATO
                   AND REF.NRORG         = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
     /* Retorna os dados de faturamento do modelo de contrato
     */
    public function getParamVencimentos(array $params) {
        $sql = "SELECT QTDIASAPURACAO, IDTPCALCVENC, NRDIACALCVENC, IDMESCALCVENC, QTDIASFATUVENC 
                  FROM FCT_PARAMFATMODCON
                 WHERE NRSEQMODCONTRA = :NRSEQMODCONTRA
                   AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }    
    
     /**
      * Retorna os produto de faturamento do serviço
     */
    public function getProdServico(array $params) {
        $sql = "SELECT CDPRODFATSERV 
                  FROM FCT_SERVICOORCA
                 WHERE CDSERVORCA = :CDSERVORCA
                   AND NRPRG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    } 
    
         /**
      * Retorna o valor total dos itens do faturamento a ser atualizado
     */
    public function getSomaValorItens(array $params) {
        $sql = "SELECT SUM(VRVENCIMENTO) AS SOMAVRVENC
                  FROM FCT_ITFATURACONT
                 WHERE NRFATURACONT = :NRFATURACONT
                   AND NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    } 
    
    /*
     * Seleciona quais dados da tabela FCT_FATURACONT será retornado para o front. 
    */
    public function getDadosUmaParcela(array $params){
      $sql ="SELECT VRVENCIMENTO, VRFALTAFATURAR
             FROM FCT_FATURACONT
             WHERE NRFATURACONT = :NRFATURACONT";
      
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Atualiza o valor da parcela de Faturamento ao alterar os itens
     */
    public function AtulizaValorFaturamento(array $params) {
        $sql = "UPDATE FCT_FATURACONT
                   SET VRVENCIMENTO   = ROUND(:VRSOMAITENS, 2),
                       VRFALTAFATURAR = ROUND(:VRSOMAITENS, 2),
                       IDALTUSUARIO   = 'S',
                       NRORGULTATU    = :NRORG,
                       DTULTATU       = SYSDATE,
                       CDOPERULTATU   = :CDOPERADOR
                 WHERE NRFATURACONT = :NRFATURACONT
                   AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    } 
    
    /* Atualiza a conexão do banco de acordo com o connection enviado.
       Atualmente  utilizado para funcionamento da rotina "atualizarMedVariavelOM" do service "Sm00012000MedicaoFaturamentoService"*/
    public function atualizaConnection($connection){
        $this->connection = $connection;
    }
    
    /**
     * Retorna o documento de acordo com a situação indicada
    **/
    public function getDocumentosSituacao(array $params){
        $sql = "SELECT FCT_MODELODOC.NRSEQMODDOCFCT,
                   FCT_MODELODOC.NRMODELODOCFCT,
                   FCT_MODELODOC.IDIDIOMA,
                   FCT_MODELODOC.TXMODELODOCORCA,
                   FCT_MODELODOC.NRORG,
                   FCT_MODELODOC.NMARQUIVO,
                   FCT_MODELODOC.DSCAMINHOARQ,
                   FCT_MODELODOC.DSTIPO,
                   FCT_MODELODOC.VRTAMANHO,
                   MODCONT.IDSITUACAOCONTRATO 
                FROM FCT_MODELODOC
                INNER JOIN (SELECT DISTINCT NRSEQMODDOCFCT, IDSITUACAOCONTRATO, NRORG
                             FROM FCT_MODELODOCCONTR
                            WHERE NRORG = :NRORG
                              AND NRSEQMODCONTRA IN (SELECT NRSEQMODCONTRA FROM FCT_CONTRATO WHERE NRSEQCONTRATO = :NRSEQCONTRATO)
                              AND (IDSITUACAOCONTRATO = :IDSITUACAOCONTRATO OR (IDSITUACAOCONTRATO IS NULL AND (SELECT COUNT(DOC.NRSEQMODDOCFCT)
                                                                                FROM FCT_MODELODOCCONTR DOC
                                                                                WHERE DOC.IDSITUACAOCONTRATO = :IDSITUACAOCONTRATO
                                                                                  AND DOC.NRSEQMODCONTRA = FCT_MODELODOCCONTR.NRSEQMODCONTRA) = 0))) MODCONT 
                ON FCT_MODELODOC.NRORG = MODCONT.NRORG
                AND FCT_MODELODOC.NRSEQMODDOCFCT = MODCONT.NRSEQMODDOCFCT
                WHERE FCT_MODELODOC.NRORG = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Atualiza na tabela de documento do contrato o documento
     * de acordo com a situação
    **/
    public function atualizaDocumentoSituacao(array $params){
        $sql = "UPDATE FCT_CONTRATODOC
                SET NRSEQMODDOCFCT    = :NRSEQMODDOCFCT,
                   NMARQUIVO          = :NMARQUIVO,
                   DSCAMINHOARQ       = :DSCAMINHOARQ,
                   DSTIPO             = :DSTIPO,
                   VRTAMANHO          = :VRTAMANHO,
                   IDSITUACAOCONTRATO = :IDSITUACAOCONTRATO 
                WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                  AND NRORG = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function retornaIntervaloDatas($dtInicio, $dtFinal) {
        $sql = "SELECT (TO_DATE('".$dtFinal."', 'DD/MM/YYYY') - TO_DATE('".$dtInicio."', 'DD/MM/YYYY'))+1 AS INTERVALO FROM DUAL";
        
        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    } 
    
    /**
     * Atualiza os operadores responáveis do contrato através da ação
     * atualizar op. responsáveis das telas de contrato e prospect
    **/
    public function atualizaOperadorResponsavel(array $params, $query){
        $sql = "UPDATE FCT_CONTRATO
                  SET CDOPERRESPONSAVEL = :NEWCDOPERADOR
                WHERE $query
                  AND NRORG             = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * A função "buscaFilialHierarquia" busca a filial vinculado ao operador 
     * na hierarquiia de operadores (CRM_HIERARQUIAOPER)
     */
     
    public function buscaFilialHierarquia(array $params) {
        $sql = "SELECT CRM_HIERARQUIAOPER.CDFILIAL, FILIAL.NMFILIAL
                  FROM CRM_HIERARQUIAOPER
                  JOIN FILIAL 
                    ON FILIAL.CDFILIAL = CRM_HIERARQUIAOPER.CDFILIAL
                   AND FILIAL.NRORG = CRM_HIERARQUIAOPER.NRORG
                  WHERE CRM_HIERARQUIAOPER.CDOPERADOR = :CDOPERADOR
                    AND CRM_HIERARQUIAOPER.NRORG = :NRORG
                    AND ROWNUM = 1
                ORDER BY CRM_HIERARQUIAOPER.DTULTATU DESC";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
     
      /* Retorna os dados de faturamento da parametrização  de contrato
     */
    public function getParamFatCont(array $params) {
        $sql = "SELECT FCT_PARAMFATCONT.CDPRODFATURA, PRODUTO.NMPRODUTO, FCT_PARAMFATCONT.CDFILIALFATURA, FILIAL.NMFILIAL, 
                       FCT_PARAMFATCONT.NRGRUPOFATURA, FCT_GRUPOFATURA.NMGRUPOFATURA, FCT_PARAMFATCONT.NRPARCFATURA, PARCNEGOCIO.NMPRINCIPALPARC, 
                       FCT_PARAMFATCONT.IDSOMAFATUCONT, FCT_PARAMFATCONT.IDSOMAITGRUPFAT, FCT_PARAMFATCONT.IDGERANFPARC, FCT_PARAMFATCONT.IDBLOQVRMEDIC, 
                       FCT_PARAMFATCONT.IDGERARATEIO, FCT_PARAMFATCONT.QTFRANQEVOLCONTR, FCT_PARAMFATCONT.IDAPURAAPONTAMENTO
                  FROM FCT_PARAMFATCONT
                  LEFT JOIN PRODUTO 
                    ON PRODUTO.CDPRODUTO = FCT_PARAMFATCONT.CDPRODFATURA
                   AND PRODUTO.NRORG = FCT_PARAMFATCONT.NRORG
                  LEFT JOIN FILIAL 
                    ON FILIAL.CDFILIAL = FCT_PARAMFATCONT.CDFILIALFATURA
                   AND FILIAL.NRORG = FCT_PARAMFATCONT.NRORG
                  LEFT JOIN FCT_GRUPOFATURA 
                    ON FCT_GRUPOFATURA.NRGRUPOFATURA = FCT_PARAMFATCONT.NRGRUPOFATURA
                   AND FCT_GRUPOFATURA.NRORG = FCT_PARAMFATCONT.NRORG
                  LEFT JOIN PARCNEGOCIO 
                    ON PARCNEGOCIO.NRPARCNEGOCIO = FCT_PARAMFATCONT.NRPARCFATURA
                   AND PARCNEGOCIO.NRORG = FCT_PARAMFATCONT.NRORG 
                 WHERE FCT_PARAMFATCONT.NRSEQCONTRATO = :NRSEQCONTRATO
                   AND FCT_PARAMFATCONT.NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /* Valida se o orçamento foi realizado através de Composição de Serviços.
     */
    public function validaCompServico(array $params) {
        $sql = "SELECT DECODE (COUNT(*), 0 ,'N', 'S') AS EXISTE 
                  FROM FCT_TRABSERVORCAMENTO
                 WHERE NRSEQORCAMENTO = :NRSEQORCAMENTO
                   AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    /**
     * Busca as informações do modelo de proposta
     * (Utilizada apenas na inserção de contratos com composição de serviço e medidas)
    **/
    public function getInfoModeloPropostaInserindo(array $params, $nrtipoorcamento){
        $sql = "SELECT DISTINCT MORCA.NRORCAMENTOMODELO,
                  MORCA.QTDIASVALIDADE,
                  MORCA.QTDIASCONTRATO,
                  MORCA.DSOBSERVACAOORCA,
                  MORCA.DSREFERENCIAORCA,
                  MORCA.CDMINEMORCA,
                  MORCA.NRDIASCARENCIA,
                  MORCA.NRGRUPOFATURA,
                  MORCA.NRDIAVENCPARCELASFATU
                FROM FCT_ORCAMENTOMODELO MORCA
                INNER JOIN FCT_RELACESCOPOMODELO ESCMOD
                  ON MORCA.NRORCAMENTOMODELO = ESCMOD.NRORCAMENTOMODELO
                  AND MORCA.NRORG            = ESCMOD.NRORG
                WHERE ESCMOD.NRTIPOORCAMENTO IN($nrtipoorcamento)
                  AND MORCA.NRORCAMENTOMODELO = :NRORCAMENTOMODELO
                  AND MORCA.NRORG             = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    /**
     * Altera as informações do contrato mantendo os dados que o usuário digitou
    **/
    public function alterarInformacoesContrato(array $params, $nrcontratos){
        $sql = "UPDATE FCT_CONTRATO 
                SET DSREFERENCIACONT = :DSREFERENCIACONT,
                    DTINICIOCONTRATO = :DTINICIOCONTRATO,
                    DTFIMCONTRATO    = :DTFIMCONTRATO,
                    NRDIASPRAZOCONT  = :NRDIASPRAZOCONT
                WHERE NRSEQCONTRATO IN($nrcontratos)
                    AND NRORG = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    /**
     * Altera a observação da proposta 
    **/
    public function alterarObservacaoProposta(array $params, $observacao){
        $sql = "UPDATE FCT_ORCAMENTO 
                SET DSOBSERVACAOORCA = '$observacao'
                WHERE NRSEQORCAMENTO = :NRSEQORCAMENTO
                    AND NRORG = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $this->alterarReferenciaPropostaContrato($params);
    }
    /**
     * Altera a observação da proposta 
    **/
    public function alterarReferenciaPropostaContrato(array $params){
        $sql = "UPDATE FCT_REFEORCACONT 
                SET IDGERADOPOR = 'CONTRATO'
                WHERE NRSEQORCAMENTO = :NRSEQORCAMENTO
                    AND NRORG        = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    /**
     * Busca os contratos gerados pela proposta adicionada pela tela de contrato 
    **/
    public function getContratosRefeOrcaCont($params){
        $sql = "SELECT ORC.DSOBSERVACAOORCA,
                  ORC.NRSEQORCAMENTO,
                  REFE.NRTIPOORCAMENTO,
                  CONT.NRSEQCONTRATO, 
                  CONT.NRCONTRATOFCT,
                  CONT.NRSEQMODCONTRA,
                  CONT.NRVERSAOCONTRATO,
                  NVL(TIPO.IDUTILIZAVARPRECO, 'N') AS IDUTILIZAVARPRECO
                FROM FCT_REFEORCACONT REFE
                INNER JOIN FCT_ORCAMENTO ORC
                  ON REFE.NRSEQORCAMENTO = ORC.NRSEQORCAMENTO
                  AND REFE.NRORG         = ORC.NRORG
                INNER JOIN FCT_CONTRATO CONT
                  ON REFE.NRSEQCONTRATO = CONT.NRSEQCONTRATO
                  AND REFE.NRORG        = CONT.NRORG
                JOIN FCT_TIPOORCAMENTO TIPO
                  ON REFE.NRTIPOORCAMENTO = TIPO.NRTIPOORCAMENTO
                  AND REFE.NRORG          = TIPO.NRORG
                WHERE REFE.NRSEQORCAMENTO = :NRSEQORCAMENTO
                  AND REFE.NRORG          = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

    public function excluirParcelasNegociacao(array $params) {
        $sql = "DELETE FROM FCT_PARCELANEGOCONT
                 WHERE NRNEGOCIACAOCONTRATO = :NRNEGOCIACAOCONTRATO
                   AND NRORG                = :NRORG";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function excluirProrrog(array $params){
        $sql = "DELETE FROM FCT_PRORROGCONTRATO
                 WHERE NRSEQPRORRCONT = :NRSEQPRORRCONT
                   AND NRORG                = :NRORG";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }

    public function inserirParcelaNegociacao(array $params) {
        $sql = "INSERT INTO FCT_PARCELANEGOCONT (
            NRPARCELANEGOCONT, NRNEGOCIACAOCONTRATO, QTDIASFATURAMENTO, 
            NRPARCELA,         NRDIAVENCIMENTO,      VRPARCELA,            
            IDATIVO,           NRORG,                DTINCLUSAO,           
            NRORGINCLUSAO,     CDOPERINCLUSAO,       NRPARCELANEGOPROP
        )
        VALUES (
            :NRPARCELANEGOCONT, :NRNEGOCIACAOCONTRATO, :QTDIASFATURAMENTO,
            :NRPARCELA,         :NRDIAVENCIMENTO,      ROUND(:VRPARCELA, 2),  
            :IDATIVO,           :NRORG,                SYSDATE,               
            :NRORGINCLUSAO,     :CDOPERINCLUSAO,       :NRPARCELANEGOPROP
        )";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function getNegociacaoValoresComSomaDasParcelas(array $params) {
        $sql = "SELECT NEG.NRNEGOCIACAOCONTRATO,
                       NEG.VRTOTITEMCOMDESC,
                       (SELECT SUM(VRPARCELA)
                          FROM FCT_PARCELANEGOCONT
                         WHERE NRNEGOCIACAOCONTRATO = NEG.NRNEGOCIACAOCONTRATO
                           AND NRORG                = NEG.NRORG) AS SOMA_PARCELAS
                  FROM FCT_NEGOCIACAOCONTRATO NEG
                 WHERE NEG.NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NEG.NRORG         = :NRORG
                   AND NEG.IDTPFATURA    = 'P'";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }

    public function getItensNegociacao(array $params) {
        $sql = "SELECT ITNEG.NRITNEGOCIACAOCONTRATO,
                       ITNEG.NRNEGOCIACAOCONTRATO,
                       ITNEG.NRITEMORCAMENTO,
                       ITNEG.VRTOTITEM,
                       ITCON.VRTOTITEMCONT
                  FROM FCT_ITNEGOCIACAOCONTRATO ITNEG
                 INNER JOIN FCT_ITEMCONTRATO ITCON
                    ON ITNEG.NRITEMORCAMENTO = ITCON.NRITEMORCAMENTO
                   AND ITNEG.NRORG           = ITCON.NRORG
                 WHERE ITNEG.NRNEGOCIACAOCONTRATO = :NRNEGOCIACAOCONTRATO
                   AND ITNEG.NRORG                = :NRORG";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }

    /**
     * Update na tabela FCT_ITNEGOCIACAOCONTRATO
    */
    public function atualizarValorItemNegociacao(array $params) {
        $sql = "UPDATE FCT_ITNEGOCIACAOCONTRATO
                   SET VRTOTITEM        = ROUND(:VRTOTITEM, 2),
                       VRDESCITEM       = ROUND((:VRTOTITEM * NVL(VRPERCDESCITEM, 0) / 100), 2),
                       VRTOTITEMCOMDESC = ROUND(:VRTOTITEM - (:VRTOTITEM * NVL(VRPERCDESCITEM, 0) / 100), 2),
                       DTULTATU         = SYSDATE,
                       CDOPERULTATU     = :CDOPERULTATU,
                       NRORGULTATU      = :NRORGULTATU
                 WHERE NRNEGOCIACAOCONTRATO = :NRNEGOCIACAOCONTRATO
                   AND NRITEMOCONTRATO      = :NRITEMOCONTRATO
                   AND NRORG                = :NRORG";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }

    public function excluirItemNegociacaoComFilhos(array $params) {
        $sql = "DELETE FROM FCT_ITNEGOCIACAOCONTRATO
                 WHERE NRNEGOCIACAOCONTRATO = :NRNEGOCIACAOCONTRATO
                   AND (NRITEMORCAMENTO     = :NRITEMORCAMENTO
                    OR NRITEMORCAMENTOPAI   = :NRITEMORCAMENTO)
                   AND NRORG                = :NRORG";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }

    public function inserirNegociacaoContrato(array $params) {
        $sql = "INSERT INTO FCT_NEGOCIACAOCONTRATO (
                    NRNEGOCIACAOCONTRATO, NRSEQCONTRATO,  NRTIPOORCAMENTO,
                    IDTPFATURA,           CDFILIALFATURA, NRPARCFATURA,
                    CDTIPOOPERFATURA,     CDSERIENF,      CDEMPRESA,
                    CDINSCESTA,           CDINSCMUNI,     VRTOTITEM,
                    VRPERCDESCITEM,       VRDESCITEM,     VRTOTITEMCOMDESC,
                    IDATIVO,              NRORG,          NRORGINCLUSAO,
                    CDOPERINCLUSAO,       DTINCLUSAO,     NRNEGOCIACAOPROPOSTA,
                    NRESTRUTURAM
                ) VALUES (
                    :NRNEGOCIACAOCONTRATO,     :NRSEQCONTRATO,        :NRTIPOORCAMENTO,
                    :IDTPFATURA,               :CDFILIALFATURA,       :NRPARCFATURA,
                    :CDTIPOOPERFATURA,         :CDSERIENF,            :CDEMPRESA,
                    :CDINSCESTA,               :CDINSCMUNI,           ROUND(:VRTOTITEM, 2),
                    ROUND(:VRPERCDESCITEM, 2), ROUND(:VRDESCITEM, 2), ROUND(:VRTOTITEMCOMDESC, 2),
                    :IDATIVO,                  :NRORG,                :NRORGINCLUSAO,
                    :CDOPERINCLUSAO,           SYSDATE,               :NRNEGOCIACAOPROPOSTA,
                    :NRESTRUTURAM
                )";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }

    public function inserirItemNegociacaoContrato(array $params) {
        $sql = "INSERT INTO FCT_ITNEGOCIACAOCONTRATO (
            NRITNEGOCIACAOCONTRATO, NRNEGOCIACAOCONTRATO, NRITEMORCAMENTO,
            NRITEMORCAMENTOPAI,     VRTOTITEM,            VRPERCDESCITEM,
            VRDESCITEM,             VRTOTITEMCOMDESC,     CDSERVORCA,
            CDPRODFATURA,           NRPARCFATURA,         IDATIVO,
            NRORG,                  NRORGINCLUSAO,        CDOPERINCLUSAO,
            DTINCLUSAO,             NRITEMOCONTRATO,      NRITNEGOCIACAOPROPOSTA,
            NRITEMCONTRATOPAI
        ) VALUES (
            :NRITNEGOCIACAOCONTRATO, :NRNEGOCIACAOCONTRATO,       :NRITEMORCAMENTO,
            :NRITEMORCAMENTOPAI,     ROUND(:VRTOTITEM, 2),        ROUND(:VRPERCDESCITEM, 2),
            ROUND(:VRDESCITEM, 2),   ROUND(:VRTOTITEMCOMDESC, 2), :CDSERVORCA,
            :CDPRODFATURA,           :NRPARCFATURA,               :IDATIVO,
            :NRORG,                  :NRORGINCLUSAO,              :CDOPERINCLUSAO,
            SYSDATE,                 :NRITEMOCONTRATO,            :NRITNEGOCIACAOPROPOSTA,
            :NRITEMCONTRATOPAI
        )";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }

    public function getSomaValorItensNegociacao(array $params) {
        $sql = "SELECT SUM(VRTOTITEMCOMDESC) AS VRTOTAL
                  FROM FCT_ITNEGOCIACAOCONTRATO
                 WHERE NRNEGOCIACAOCONTRATO = :NRNEGOCIACAOCONTRATO
                   AND NRORG                = :NRORG
                   AND NRITEMCONTRATOPAI IS NULL";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }

    public function getSomaValorElementosItemNegociacao(array $params) {
        $sql = "SELECT SUM(VRTOTITEMCOMDESC) AS VRTOTAL
                  FROM FCT_ITNEGOCIACAOCONTRATO
                 WHERE NRNEGOCIACAOCONTRATO = :NRNEGOCIACAOCONTRATO
                   AND NRITEMCONTRATOPAI    = :NRITEMOCONTRATO
                   AND NRORG                = :NRORG";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }

    /**
     * Update na tabela FCT_NEGOCIACAOCONTRATO
    */
    public function atualizarValorNegociacaoComSomaDosItens(array $params) {
        $sql = "UPDATE FCT_NEGOCIACAOCONTRATO
                   SET VRTOTITEM        = ROUND(:VRTOTAL, 2),
                       VRDESCITEM       = ROUND((:VRTOTAL * NVL(VRPERCDESCITEM, 0) / 100), 2),
                       VRTOTITEMCOMDESC = ROUND(:VRTOTAL - (:VRTOTAL * NVL(VRPERCDESCITEM, 0) / 100), 2),
                       DTULTATU         = SYSDATE,
                       CDOPERULTATU     = :CDOPERULTATU,
                       NRORGULTATU      = :NRORGULTATU
                 WHERE NRNEGOCIACAOCONTRATO = :NRNEGOCIACAOCONTRATO
                   AND NRORG                = :NRORG";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }

    public function getDescontosPorPeriodoDaNegociacao(array $params) {
        $sql = "SELECT NRDESCPERIODONEGOCONT,
                       VRPERCDESCITEM,
                       VRDESCITEM,
                       VRTOTITEMCOMDESC,
                       QTMESESDESC,
                       DTFINALVALIDADEDESC,
                       IDATIVO,
                       NRORDEMAPLICADESC,
                       NRNEGOCIACAOCONTRATO,
                       DTINCLUSAO,
                       NRORGINCLUSAO,
                       CDOPERINCLUSAO,
                       DTULTATU,
                       NRORGULTATU,
                       CDOPERULTATU,
                       IDTPDESCONTO
                FROM FCT_DESCPERIODONEGOCONT
                WHERE NRNEGOCIACAOCONTRATO = :NRNEGOCIACAOCONTRATO
                   AND NRORG               = :NRORG
                ORDER BY NRORDEMAPLICADESC";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }

    public function atualizarValorDescontoPorPeriodoDaNegociacao(array $params) {
        $sql = "UPDATE FCT_DESCPERIODONEGOCONT
                   SET VRDESCITEM       = ROUND((:VRTOTITEM * VRPERCDESCITEM / 100), 2),
                       VRTOTITEMCOMDESC = ROUND(:VRTOTITEM - (:VRTOTITEM * VRPERCDESCITEM / 100), 2),
                       DTULTATU         = SYSDATE,
                       CDOPERULTATU     = :CDOPERULTATU,
                       NRORGULTATU      = :NRORGULTATU
                 WHERE NRDESCPERIODONEGOCONT = :NRDESCPERIODONEGOCONT
                   AND NRORG                 = :NRORG";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }

    public function getQuantidadeItensNegociacaoContrato(array $params) {
        $sql = "SELECT COUNT(*) AS QTDE
                  FROM FCT_ITNEGOCIACAOCONTRATO
                 WHERE NRNEGOCIACAOCONTRATO = :NRNEGOCIACAOCONTRATO
                   AND NRORG                = :NRORG
                   AND NRITEMCONTRATOPAI   IS NULL";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }

    public function getCompetenciaNegociacaoContrato(array $params) {
        $sql = "SELECT NRCOMPETENCIANEGOCONT,
                       NRDIACOMPETINI,
                       NRDIACOMPETFIN,
                       IDMESCOMPETINI,
                       IDMESCOMPETFIN,
                       QTDIASAPURACAO,
                       IDTPCALCVENC,
                       NRDIACALCVENC,
                       IDMESCALCVENC,
                       QTDIASFATUVENC,
                       IDATIVO
                  FROM FCT_COMPETENCIANEGOCONT
                 WHERE NRNEGOCIACAOCONTRATO = :NRNEGOCIACAOCONTRATO
                   AND NRORG                = :NRORG
                 ORDER BY IDMESCOMPETINI, NRDIACOMPETINI";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }

    public function atualizarDataFinalValidadeDescontoPorPeriodo(array $params) {
        $sql = "UPDATE FCT_DESCPERIODONEGOCONT
                   SET DTFINALVALIDADEDESC   = :DTFINALVALIDADEDESC
                 WHERE NRDESCPERIODONEGOCONT = :NRDESCPERIODONEGOCONT
                   AND NRORG                 = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }

    /**
     * Busca os parâmetros de paralisação que terão o faturamento
     * retomado
    **/
    public function getParamParalisacao($params) {
        $sql = "SELECT TO_CHAR(DTINIPARALISACAO, 'DD/MM/YYYY') AS DTINIPARALISACAO,
                    TO_CHAR(DTRETOMADAFATURA, 'DD/MM/YYYY') AS DTRETOMADAFATURA
                FROM FCT_PARAMPARALISACAOCONT
                WHERE NRSEQCONTRATO      = :NRSEQCONTRATO
                    AND NRORG            = :NRORG
                    AND NRPARAMPARALISAO = :NRPARAMPARALISAO";
        $std = $this->connection->prepare($sql); 
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Atualiza a data de retormada da paralização de um contrato 
    **/
    public function alterarDtRetomadaParalisacao(array $params) {
        $sql = "UPDATE FCT_PARAMPARALISACAOCONT
                SET DTRETOMADAFATURA = SYSDATE,
                    DTULTATU         = SYSDATE,
                    DSMOTIVORETOMADA = :DSMOTIVORETOMADA,
                    CDOPERULTATU     = :CDOPERADOR
                WHERE NRSEQCONTRATO     = :NRSEQCONTRATO
                   AND NRORG            = :NRORG
                   AND NRPARAMPARALISAO = :NRPARAMPARALISAO";
        $std = $this->connection->prepare($sql); 
        $std->execute($params);
    }
    
    /**
     * Retorna as medições que serão paralisadas
    **/
    public function getMedicoesPorPeriodo(array $params, $situacoes) {
        $sql = "SELECT LISTAGG(NRMEDICAOFATURA, ',') WITHIN GROUP (ORDER BY NRMEDICAOFATURA) AS NRMEDICAOFATURA
                  FROM FCT_MEDICAOFATURA
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG         = :NRORG
                   AND IDSITUACAO    IN ($situacoes)
                   AND (TRUNC(DTINICOMPET) BETWEEN :DTINICOMPET AND :DTFINCOMPET
                       OR TRUNC(DTFINCOMPET) BETWEEN :DTINICOMPET AND :DTFINCOMPET)";
        $std = $this->connection->prepare($sql); 
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Altera o status de uma medicao
    **/
    public function alterarStatusMedicao(array $params, $nrmedicoes) {
        $sql = "UPDATE FCT_MEDICAOFATURA
                SET IDSITUACAO   = :IDSITUACAO,
                    CDOPERULTATU = :CDOPERADOR
                WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                    AND NRORG       = :NRORG
                    AND NRMEDICAOFATURA IN($nrmedicoes)";
        $std = $this->connection->prepare($sql); 
        $std->execute($params);
    }
    
    /**
     * Altera a situação do item da medição
    **/
    public function alterarStatusMedicaoItens(array $params, $nrmedicoes) {
        $sql = "UPDATE FCT_ITMEDICAOFATURA
                SET IDSITUACAO   = :IDSITUACAO,
                    CDOPERULTATU = :CDOPERADOR
                WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                    AND NRORG       = :NRORG
                    AND NRMEDICAOFATURA IN($nrmedicoes)";
        $std = $this->connection->prepare($sql); 
        $std->execute($params);
    }
    
    /**
     * Retorna as parcelas de um período determinado
    **/
    public function getParcelasPorPeriodo(array $params, $situacoes) {
        $sql = "SELECT LISTAGG(FAT.NRFATURACONT, ',') WITHIN GROUP (ORDER BY FAT.NRFATURACONT) AS NRFATURACONT
                  FROM FCT_FATURACONT FAT
                 INNER JOIN FCT_RELACAGRUPCONTFAT RELACFAT
                    ON FAT.NRFATURACONT       = RELACFAT.NRFATURACONT
                   AND FAT.NRORG              = RELACFAT.NRORG
                 WHERE FAT.NRORG              = :NRORG
                   AND FAT.IDSITUACAO         IN ($situacoes)
                   AND RELACFAT.NRSEQCONTRATO = :NRSEQCONTRATO
                   AND (TRUNC(FAT.DTINICOMPET) BETWEEN :DTINICOMPET AND :DTFINCOMPET
                       OR TRUNC(FAT.DTFINCOMPET) BETWEEN :DTINICOMPET AND :DTFINCOMPET)";
        $std = $this->connection->prepare($sql); 
        $std->execute($params);
        return $std->fetchAll();
    } 
    /**
     * Altera o status da parcela
    **/
    public function alterarStatusParcelas(array $params, $nrfaturacont) {
        $sql = "UPDATE FCT_FATURACONT
                SET IDSITUACAO = :IDSITUACAO,
                  CDOPERULTATU = :CDOPERADOR
                WHERE NRORG    = :NRORG
                    AND NRFATURACONT IN ($nrfaturacont)";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    /**
     * Altera o status dos itens da parcela
    **/
    public function alterarStatusParcelasItens(array $params, $nrfaturacont) {
        $sql = "UPDATE FCT_ITFATURACONT
                SET IDSITUACAO = :IDSITUACAO,
                  CDOPERULTATU = :CDOPERADOR
                WHERE NRORG    = :NRORG
                    AND NRFATURACONT IN ($nrfaturacont)";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }

    public function atualizarParceiroNegociacoesContrato(array $params) {
        $sql = "UPDATE FCT_NEGOCIACAOCONTRATO
                   SET NRPARCFATURA = :NRPARCFATURA,
                       DTULTATU     = SYSDATE,
                       NRORGULTATU  = :NRORGULTATU,
                       CDOPERULTATU = :CDOPERULTATU
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG         = :NRORG";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }

    public function atualizarParceiroItensNegociacoesContrato(array $params) {
        $sql = "UPDATE FCT_ITNEGOCIACAOCONTRATO
                   SET NRPARCFATURA = :NRPARCFATURA,
                       DTULTATU     = SYSDATE,
                       NRORGULTATU  = :NRORGULTATU,
                       CDOPERULTATU = :CDOPERULTATU
                 WHERE NRNEGOCIACAOCONTRATO IN (SELECT NRNEGOCIACAOCONTRATO
                                                  FROM FCT_NEGOCIACAOCONTRATO
                                                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                                                   AND NRORG         = :NRORG)
                  AND NRORG = :NRORG";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    /**
     * Retorna os itens de determinado contrato
    **/
    public function getItensContratos(array $params) {
        $sql = "SELECT NRITEMOCONTRATO,
                     NRSEQCONTRATO,
                     NMITEMCONTRATO,
                     CDSERVORCA,
                     QTITEMCONTRATO,
                     VRUNITITEMCONT,
                     VRTOTITEMCONT,
                     QTMEDIDACONTR,
                     IDELEMENTO,
                     CDTPMEDIDASERV,
                     NMCONTRATUALITEMCONT,
                     CDTPMEDIDAVARIAVEL,
                     VRUNITITEMCONTTBLPRECO,
                     QTMEDIDACALCULADA,
                     CDOPERINCLUSAO,
                     DECODE(IDELEMENTO, NULL, 0, VRUNITITEMCONT - VRUNITITEMCONTTBLPRECO) AS VRACRESCIMOITEM,
                     NRITEMCONTRATOPAI,
                     IDELEMENTO,
                     NRESTRUTURAM
                FROM FCT_ITEMCONTRATO
                WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                 AND NRORG          = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    /**
     * Deleta os tipos de medidas relacionados a um determinado 
     * contrato
    **/
    public function deletarTiposMedidaContrato(array $params) {
        $sql = "DELETE FROM FCT_RELACMEDIDACONTRATO
                WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                    AND NRORG       = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    /**
     * Deleta os elementos ligados a um determinado contrato
    **/
    public function excluirElementosContrato(array $params) {
        $sql = "DELETE FROM FCT_TRABSERVCONTRATO
                WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                    AND NRORG       = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    /**
     * Deleta as composições ligadds a um determinado contrato
    **/
    public function excluirComposicoesContrato(array $params) {
        $sql = "DELETE FROM FCT_COMPSERVCONTRATO
                WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                    AND NRORG       = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    /**
     * Deleta os itens de um contrato
    **/
    public function excluirItensContrato(array $params) {
        $sql = "DELETE FROM FCT_ITEMCONTRATO
                WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                    AND NRORG       = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    /**
     * Retorna a negociação de valores de um contrato
    **/
    public function excluirNegociacaoDeValoresContrato($params) {
        $sql = "DELETE FROM FCT_NEGOCIACAOCONTRATO
                WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG        = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    /**
     * Insere um relacionamento entre contratos e medida variável
    **/
    public function inserirTipoDeMedidaContrato(array $params) {
        $sql = "INSERT INTO FCT_RELACMEDIDACONTRATO (
                    NRMEDIDACONTRATO,   NRSEQCONTRATO,  CDTPMEDIDAVARIAVEL,
                    QTMEDIDAVARIAVEL,   IDELEMENTORAIZ, QTFRANQUIA,
                    NRORG,              DTINCLUSAO,     DTULTATU,
                    NRORGINCLUSAO,      CDOPERINCLUSAO, NRORGULTATU,
                    CDOPERULTATU,       IDATIVO,        NRTIPOORCAMENTO,
                    IDAPARECEPROPOSTA
                ) VALUES (
                    :NRMEDIDACONTRATO,           :NRSEQCONTRATO,  :CDTPMEDIDAVARIAVEL,
                    ROUND(:QTMEDIDAVARIAVEL, 2), :IDELEMENTORAIZ, :QTFRANQUIA,
                    :NRORG,                      SYSDATE,         NULL,
                    :NRORGINCLUSAO,              :CDOPERINCLUSAO, NULL,
                    NULL,                        :IDATIVO,        :NRTIPOORCAMENTO,
                    :IDAPARECEPROPOSTA
                )";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    /**
     * Insere um relacionamento de um elemento com o contrato
    **/
    public function inserirElementosContrato(array $params) {
        $sql = "INSERT INTO FCT_TRABSERVCONTRATO (
                    NRTRABSERVCONT,  NRSEQCONTRATO,    NRTIPOORCAMENTO,
                    NRCOMPSERVICO,   NRITCOMPSERVICO,  IDESCOLHIDO,
                    CDSERVORCA,      QTSERVORCA,       CDTPMEDIDASERV,
                    QTMEDSERVORCA,   VRUNITSERVORCA,   VRTOTSERVORCA,
                    IDELEMENTO,      IDELEMENTOPAI,    IDTIPOELEMENTO,
                    IDSERVOBRIGCOMP, QTMEDIDAVARIAVEL, QTMEDIDACALC,
                    NRORG,           IDATIVO,          DTINCLUSAO,
                    DTULTATU,        NRORGINCLUSAO,    CDOPERINCLUSAO,
                    NRORGULTATU,     CDOPERULTATU,     IDAPARECEPROPOSTA
                ) VALUES (
                    :NRTRABSERVCONT,          :NRSEQCONTRATO,              :NRTIPOORCAMENTO,
                    :NRCOMPSERVICO,           :NRITCOMPSERVICO,            :IDESCOLHIDO,
                    :CDSERVORCA,              ROUND(:QTSERVORCA, 2),       :CDTPMEDIDASERV,
                    ROUND(:QTMEDSERVORCA, 2), ROUND(:VRUNITSERVORCA, 2),   ROUND(:VRTOTSERVORCA, 2),
                    :IDELEMENTO,              :IDELEMENTOPAI,              :IDTIPOELEMENTO,
                    :IDSERVOBRIGCOMP,         ROUND(:QTMEDIDAVARIAVEL, 2), ROUND(:QTMEDIDACALC, 2),
                    :NRORG,                   :IDATIVO,                    SYSDATE,
                    NULL,                     :NRORGINCLUSAO,              :CDOPERINCLUSAO,
                    NULL,                     NULL,                        :IDAPARECEPROPOSTA
                )";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    /**
     * Insere um relacionamento entre o contrato e suas composições
    **/
    public function inserirComposicoesContrato(array $params) {
        $sql = "INSERT INTO FCT_COMPSERVCONTRATO (
                    NRCOMPSERVCONT,    NRSEQCONTRATO,    NRCOMPSERVICO,
                    NMCOMPSERVICO,     NRCOMPSERVICOPAI, IDCOMPOBRIGATORIA,
                    IDESCOLHIDO,       NRORG,            IDATIVO,
                    DTINCLUSAO,        DTULTATU,         NRORGINCLUSAO,
                    CDOPERINCLUSAO,    NRORGULTATU,      CDOPERULTATU
                ) VALUES (
                    :NRCOMPSERVCONT,    :NRSEQCONTRATO,    :NRCOMPSERVICO,
                    :NMCOMPSERVICO,     :NRCOMPSERVICOPAI, :IDCOMPOBRIGATORIA,
                    :IDESCOLHIDO,       :NRORG,            :IDATIVO,
                    SYSDATE,            NULL,              :NRORGINCLUSAO,
                    :CDOPERINCLUSAO,    NULL,              NULL
                )";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    /**
     * insere itens no contrato
    **/
    public function inserirItensContrato(array $params){
        $sql = "INSERT INTO FCT_ITEMCONTRATO
                (NRORG,                  NRITEMOCONTRATO,       NRSEQCONTRATO,     CDPRODUTO, 
                 CDSERVORCA,             SGUNIDADE,             NMITEMCONTRATO,    QTITEMCONTRATO, 
                 CDTPMEDIDASERV,         QTMEDIDACONTR,         IDUNIDTEMPOSERV,   QTTEMPOSERV, 
                 IDITEMATIVO,            VRUNITITEMCONT,        VRTOTITEMCONT,     DTINICFATCONTR, 
                 IDMULTMEDVRTOT,         IDADICITEMCONT,        IDADICCOBRCONT,    IDFATURAITEM, 
                 QTPARCELASFATU,         NRDIAVENCPARCELASFATU, VRDESCONTO,        IDTPDESCONTO,
                 VRUNITITEMCONTTBLPRECO, CDTPMEDIDAVARIAVEL,    NRITEMCONTRATOPAI, IDELEMENTO,
                 NRITEMORCAMENTO,        QTMEDIDACALCULADA,     IDAPARECEPROPOSTA)
                VALUES 
                (:NRORG,                            :NRITEMOCONTRATO,             :NRSEQCONTRATO,           :CDPRODUTO, 
                 :CDSERVORCA,                       :SGUNIDADE,                   :NMITEMCONTRATO,          ROUND(:QTITEMCONTRATO, 2), 
                 :CDTPMEDIDASERV,                   ROUND(:QTMEDIDACONTR, 2),     :IDUNIDTEMPOSERV,         :QTTEMPOSERV, 
                 :IDITEMATIVO,                      ROUND(:VRUNITITEMCONT, 2),    ROUND(:VRTOTITEMCONT, 2), :DTINICFATCONTR, 
                 :IDMULTMEDVRTOT,                   :IDADICITEMCONT,              :IDADICCOBRCONT,          :IDFATURAITEM, 
                 ROUND(:QTPARCELASFATU, 2),         :NRDIAVENCPARCELASFATU,       ROUND(:VRDESCONTO, 2),    :IDTPDESCONTO,
                 ROUND(:VRUNITITEMCONTTBLPRECO, 2), :CDTPMEDIDAVARIAVEL,          :NRITEMCONTRATOPAI,       :IDELEMENTO,
                 :NRITEMORCAMENTO,                  ROUND(:QTMEDIDACALCULADA, 2), :IDAPARECEPROPOSTA)";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    /**
     * Retorna os tipos de medida variáveis ligados a um contrato
    **/
    public function getVariacoesPrecoContrato(array $params) {
        $sql = "SELECT REL.NRMEDIDACONTRATO,
                       REL.CDTPMEDIDAVARIAVEL AS CDTPMEDIDASERV,
                       REL.QTMEDIDAVARIAVEL AS QUANTIDADE,
                       REL.IDELEMENTORAIZ,
                       ELE.NMSERVORCA AS NMELEMENTORAIZ,
                       REL.NRSEQCONTRATO,
                       REL.NRORG,
                       REL.QTFRANQUIA
                FROM FCT_RELACMEDIDACONTRATO REL
                INNER JOIN FCT_SERVICOORCA ELE
                    ON REL.IDELEMENTORAIZ = ELE.IDELEMENTO
                    AND REL.NRORG         = ELE.NRORG
                WHERE REL.NRSEQCONTRATO = :NRSEQCONTRATO
                   AND REL.NRORG        = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    /**
     * Retorna todos os elementos escolhidos de um contrato
    **/
    public function getElementosEscolhidos(array $params) {
        $sql = "SELECT DISTINCT IDELEMENTO, NRCOMPSERVICO, IDAPARECEPROPOSTA
                FROM FCT_TRABSERVCONTRATO
                WHERE NRSEQCONTRATO  = :NRSEQCONTRATO
                   AND NRORG         = :NRORG
                   AND IDESCOLHIDO   = 'S'";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    /**
     * Retorna todas as composições de serviço vinculadas a um contrato
    **/
    public function getComposicoesContrato(array $params) {
        $sql = "SELECT NRCOMPSERVICO,
                       NMCOMPSERVICO,
                       NRCOMPSERVICOPAI,
                       IDCOMPOBRIGATORIA,
                       IDESCOLHIDO
                FROM FCT_COMPSERVCONTRATO
                WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                    AND NRORG       = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    /**
     * Retorna os parametros de faturamento do escopo ligado a um contrato
    **/
    public function getParametrosFaturamentoItensNegociacaoContrato(array $params, $escopos, $servicos) {
        $sql = " SELECT NRTIPOORCAMENTO,
                        CDSERVORCA,
                        NRSEQCONTRATO,
                        NRITEMOCONTRATO,
                        NRITEMCONTRATOPAI,
                        NMITEMCONTRATO,
                        VRTOTITEMCONT,
                        IDTPFATURA,
                        CDTIPOOPERFATURA,
                        CDSERIENF,
                        CDEMPRESA,
                        CDINSCESTA,
                        CDINSCMUNI,
                        CDPRODFATURA,
                        CDFILIALFATURA,
                        NRPARCFATURA,
                        DECODE(IDTPFATURA, 'P', QTPARCELASFATU, NULL) AS QTPARCELASFATU,
                        DECODE(IDTPFATURA, 'P', QTDIASAPURACAO, NULL) AS QTDIASAPURACAO,
                        DECODE(IDTPFATURA, 'P', NRDIACALCVENC, NULL) AS NRDIACALCVENC,
                        DECODE(IDTPFATURA, 'P', QTDIASFATUVENC, NULL) AS QTDIASFATUVENC,
                        DECODE(IDTPFATURA, 'P', IDTPCALCVENC, NULL) AS IDTPCALCVENC,
                        DECODE(IDTPFATURA, 'P', IDMESCALCVENC, NULL) AS IDMESCALCVENC,
                        DECODE(IDTPFATURA, 'P', 0, (SELECT COUNT(CIT.NRPARAMFATITESCSERV)
                                                    FROM FCT_PARAMFATITESCSERV CIT
                                                    INNER JOIN FCT_ITESCOPOPROPOSTA ITESC
                                                        ON CIT.NRITESCOPOPROPOSTA = ITESC.NRITESCOPOPROPOSTA
                                                        AND CIT.NRORG             = ITESC.NRORG
                                                    WHERE ITESC.NRTIPOORCAMENTO = TBL.NRTIPOORCAMENTO
                                                        AND ITESC.CDSERVORCA    = TBL.CDSERVORCA)) AS QTCOMPETENCIA
                    FROM (SELECT ITESC.NRTIPOORCAMENTO,
                                 ITESC.CDSERVORCA,
                                 ITCONT.NRITEMOCONTRATO,
                                 ITCONT.NRITEMCONTRATOPAI,
                                 ITCONT.NMITEMCONTRATO,
                                 ITCONT.VRTOTITEMCONT,
                                 ITCONT.NRSEQCONTRATO,
                                 NVL(PFIT.IDTPFATURA, PFESC.IDTPFATURA) AS IDTPFATURA,
                                 NVL(PFIT.CDTIPOOPERFATURA, PFESC.CDTIPOOPERFATURA) AS CDTIPOOPERFATURA,
                                 NVL(PFPARCIT.CDSERIENF, NVL(PFPARCESC.CDSERIENF, NVL(PFPARCCONT.CDSERIENF, NVL(PFIT.CDSERIENF, PFESC.CDSERIENF)))) AS CDSERIENF,
                                 NVL(PFPARCIT.CDEMPRESA, NVL(PFPARCESC.CDEMPRESA, NVL(PFPARCCONT.CDEMPRESA, NVL(PFIT.CDEMPRESA, PFESC.CDEMPRESA)))) AS CDEMPRESA,
                                 NVL(PFPARCIT.CDINSCESTA, NVL(PFPARCESC.CDINSCESTA, NVL(PFPARCCONT.CDINSCESTA, NVL(PFIT.CDINSCESTA, PFESC.CDINSCESTA)))) AS CDINSCESTA,
                                 NVL(PFPARCIT.CDINSCMUNI, NVL(PFPARCESC.CDINSCMUNI, NVL(PFPARCCONT.CDINSCMUNI, NVL(PFIT.CDINSCMUNI, PFESC.CDINSCMUNI)))) AS CDINSCMUNI,
                                 NVL(PFIT.CDPRODFATURA, NVL(PFESC.CDPRODFATURA, SERV.CDPRODFATSERV)) AS CDPRODFATURA,
                                 NVL(PFPARCIT.CDFILIALFATURA, NVL(PFPARCESC.CDFILIALFATURA, NVL(PFPARCCONT.CDFILIALFATURA, NVL(PFIT.CDFILIALFATURA, NVL(PFESC.CDFILIALFATURA, CONT.CDFILIALORCA))))) AS CDFILIALFATURA,
                                 NVL(PFIT.NRPARCFATURA, NVL(PFESC.NRPARCFATURA, CONT.NRPARCNEGOCIO)) AS NRPARCFATURA,
                                 NVL(PFIT.QTPARCELASFATU, PFESC.QTPARCELASFATU) AS QTPARCELASFATU,
                                 NVL(PFIT.QTDIASAPURACAO, PFESC.QTDIASAPURACAO) AS QTDIASAPURACAO,
                                 NVL(PFIT.NRDIACALCVENC, PFESC.NRDIACALCVENC) AS NRDIACALCVENC,
                                 NVL(PFIT.QTDIASFATUVENC, PFESC.QTDIASFATUVENC) AS QTDIASFATUVENC,
                                 NVL(PFIT.IDTPCALCVENC, PFESC.IDTPCALCVENC) AS IDTPCALCVENC,
                                 NVL(PFIT.IDMESCALCVENC, PFESC.IDMESCALCVENC) AS IDMESCALCVENC
                             FROM FCT_ITESCOPOPROPOSTA ITESC
                             INNER JOIN FCT_SERVICOORCA SERV
                                 ON ITESC.CDSERVORCA = SERV.CDSERVORCA
                                 AND ITESC.NRORG      = SERV.NRORG
                             LEFT JOIN FCT_PARAMFATITESC PFIT
                                 ON ITESC.NRTIPOORCAMENTO     = PFIT.NRTIPOORCAMENTO
                                 AND ITESC.NRITESCOPOPROPOSTA = PFIT.NRITESCOPOPROPOSTA
                                 AND ITESC.NRORG = PFIT.NRORG
                             LEFT JOIN PAR_PARAMFATURA PFPARCIT
                               ON PFPARCIT.NRPARCNEGOCIO = PFIT.NRPARCFATURA
                              AND PFPARCIT.NRORG = PFIT.NRORG
                             LEFT JOIN FCT_CAPAPARAMFATESC PFESC
                                 ON ITESC.NRTIPOORCAMENTO = PFESC.NRTIPOORCAMENTO
                                 AND ITESC.NRORG          = PFESC.NRORG
                              LEFT JOIN PAR_PARAMFATURA PFPARCESC
                                ON PFPARCESC.NRPARCNEGOCIO = PFESC.NRPARCFATURA
                               AND PFPARCESC.NRORG = PFESC.NRORG
                             INNER JOIN FCT_RELACESCOPOMODCONT ESCMOD
                                 ON ITESC.NRTIPOORCAMENTO  = ESCMOD.NRTIPOORCAMENTO
                                 AND ITESC.NRORG           = ESCMOD.NRORG
                                 AND ESCMOD.NRSEQMODCONTRA = :NRSEQMODCONTRA
                             INNER JOIN FCT_CONTRATO CONT
                                 ON CONT.NRSEQCONTRATO = :NRSEQCONTRATO
                                 AND ITESC.NRORG       = CONT.NRORG
                             LEFT JOIN PAR_PARAMFATURA PFPARCCONT
                               ON PFPARCCONT.NRPARCNEGOCIO = CONT.NRPARCNEGOCIO
                              AND PFPARCCONT.NRORG = CONT.NRORG
                             INNER JOIN FCT_ITEMCONTRATO ITCONT
                                 ON CONT.NRSEQCONTRATO     = ITCONT.NRSEQCONTRATO
                                 AND CONT.NRORG            = ITCONT.NRORG
                                 AND ITESC.CDSERVORCA      = ITCONT.CDSERVORCA
                                 AND ITCONT.IDADICITEMCONT = 'N'
                                 AND ITCONT.IDELEMENTO IS NULL
                             WHERE ITESC.NRORG = :NRORG
                                AND ITESC.NRTIPOORCAMENTO IN ($escopos)
                                AND ITESC.CDSERVORCA IN ($servicos)) TBL
                     ORDER BY NRTIPOORCAMENTO,
                         IDTPFATURA,
                         NRSEQCONTRATO,
                         CDTIPOOPERFATURA,
                         CDSERIENF,
                         CDEMPRESA,
                         CDINSCESTA,
                         CDINSCMUNI,
                         CDFILIALFATURA,
                         NRPARCFATURA,
                         QTPARCELASFATU,
                         QTDIASAPURACAO,
                         NRDIACALCVENC,
                         QTDIASFATUVENC,
                         IDTPCALCVENC,
                         IDMESCALCVENC,
                         QTCOMPETENCIA";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    /**
     * Retorna os itens filhos de uma árvore 
    **/
    public function getItensFilhosItemContrato($params){
        $sql = "SELECT NRITEMOCONTRATO,
                    NRITEMCONTRATOPAI,
                    VRTOTITEMCONT,
                    CDSERVORCA
                FROM FCT_ITEMCONTRATO
                WHERE NRSEQCONTRATO       = :NRSEQCONTRATO
                   AND NRITEMCONTRATOPAI  = :NRITEMCONTRATOPAI
                   AND NRORG              = :NRORG
                   AND IDADICITEMCONT      = 'N'";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    /**
     * Insere as informações da compotência ligada ao contrato 
    **/
    public function inserirCompetenciaNegociacaoContrato(array $params) {
        $sql = "INSERT INTO FCT_COMPETENCIANEGOCONT(
                    NRCOMPETENCIANEGOCONT,    NRNEGOCIACAOCONTRATO,    NRDIACOMPETINI,
                    NRDIACOMPETFIN,           IDMESCOMPETINI,          IDMESCOMPETFIN,
                    QTDIASAPURACAO,           IDTPCALCVENC,            NRDIACALCVENC,
                    IDMESCALCVENC,            QTDIASFATUVENC,          NRCOMPETENCIANEGOPROP,
                    IDATIVO,                  NRORG,                   DTINCLUSAO,
                    NRORGINCLUSAO,            CDOPERINCLUSAO,          DTULTATU,
                    NRORGULTATU,              CDOPERULTATU
                ) VALUES (
                    :NRCOMPETENCIANEGOCONT,    :NRNEGOCIACAOCONTRATO,    :NRDIACOMPETINI,
                    :NRDIACOMPETFIN,           :IDMESCOMPETINI,          :IDMESCOMPETFIN,
                    :QTDIASAPURACAO,           :IDTPCALCVENC,            :NRDIACALCVENC,
                    :IDMESCALCVENC,            :QTDIASFATUVENC,          :NRCOMPETENCIANEGOPROP,
                    :IDATIVO,                  :NRORG,                   SYSDATE,
                    :NRORGINCLUSAO,            :CDOPERINCLUSAO,          NULL,
                    NULL,                      NULL
                )";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    /**
     * Busca as informações das variações de preços ligadas 
     * ao contrato no instante da aprovação
    **/
    public function getVariacaoPrecoBaseContrato(array $params) {
        $sql = "SELECT DISTINCT VARIACOES.DTINCLUSAO AS DTINIPBSERV,
                  VARIACOES.CDTPMEDIDASERV,
                  TO_CHAR(VARIACOES.CDTPMEDIDAVARIAVEL) AS CDTPMEDIDAVARIAVEL,
                  VARIACOES.QTMEDIDAINIVARIACAO,
                  VARIACOES.QTMEDIDAFIMVARIACAO,
                  VARIACOES.VRPRECOVARIACAO,
                  NULL AS DTFIMVALPBSERV,
                  VARIACOES.IDMULTIPVARIACAO,
                  VARIACOES.CDSERVORCA,
                  VARIACOES.QTFRANQUIA
                FROM FCT_VARPRECBASESERVORCA VARIACOES
                JOIN FCT_REFEORCACONT REFE
                  ON REFE.NRSEQORCAMENTO = VARIACOES.NRSEQORCAMENTO
                  AND REFE.NRORG         = VARIACOES.NRORG
                JOIN FCT_CONTRATO CONT
                  ON REFE.NRSEQCONTRATO = CONT.NRSEQCONTRATO
                  AND REFE.NRORG        = CONT.NRORG
                WHERE CONT.NRVERSAOCONTRATO = 1
                  AND CONT.NRSEQCONTRATO    = :NRSEQCONTRATO
                  AND VARIACOES.CDSERVORCA IN(SELECT DISTINCT CDSERVORCA
                                                FROM FCT_ITEMCONTRATO
                                               WHERE NRSEQCONTRATO = CONT.NRSEQCONTRATO)
                UNION ALL 
                SELECT DISTINCT DECODE(RELACSERV.IDMEDIDAFIXA, 'S', ITVAR.DTINIPBSERV, NVL(VAR.DTINIPBSERV, ITVAR.DTINIPBSERV)) AS DTINIPBSERV,
                  DECODE(RELACSERV.IDMEDIDAFIXA, 'S', ITVAR.CDTPMEDIDASERV,            NVL(VAR.CDTPMEDIDASERV, ITVAR.CDTPMEDIDASERV)) AS CDTPMEDIDASERV,
                  DECODE(RELACSERV.IDMEDIDAFIXA, 'S', NULL,                            VAR.CDTPMEDIDAVARIAVEL) AS CDTPMEDIDAVARIAVEL,
                  DECODE(RELACSERV.IDMEDIDAFIXA, 'S', 0,                               NVL(VAR.QTMEDIDAINIVARIACAO, 0)) AS QTMEDIDAINIVARIACAO,
                  DECODE(RELACSERV.IDMEDIDAFIXA, 'S', 99999999,                        NVL(VAR.QTMEDIDAFIMVARIACAO, 99999999)) AS QTMEDIDAFIMVARIACAO,
                  DECODE(RELACSERV.IDMEDIDAFIXA, 'S', ITVAR.VRPRECO,                   NVL(VAR.VRPRECOVARIACAO, ITVAR.VRPRECO)) AS VRPRECOVARIACAO,
                  DECODE(RELACSERV.IDMEDIDAFIXA, 'S', ITVAR.DTFIMVALPBSERV,            NVL(VAR.DTFIMVALPBSERV, ITVAR.DTFIMVALPBSERV)) AS DTFIMVALPBSERV,
                  NVL(DECODE(RELACSERV.IDMEDIDAFIXA, 'S', NULL,                        VAR.IDMULTIPVARIACAO), 'N') AS IDMULTIPVARIACAO,
                  TRAB.CDSERVORCA, 
                  VAR.QTFRANQUIA
                FROM FCT_CONTRATO CONT
                INNER JOIN FCT_REFEORCACONT REFE
                  ON CONT.NRSEQCONTRATO = REFE.NRSEQCONTRATO
                  AND CONT.NRORG        = REFE.NRORG
                INNER JOIN FCT_TRABSERVCONTRATO TRAB 
                  ON CONT.NRSEQCONTRATO = TRAB.NRSEQCONTRATO
                  AND CONT.NRORG        = TRAB.NRORG
                INNER JOIN FCT_ITPRECBASESERV ITVAR
                  ON TRAB.CDSERVORCA  = ITVAR.CDSERVORCA
                  AND TRAB.NRORG      = ITVAR.NRORG
                INNER JOIN FCT_TIPOORCAMENTO TIPO
                  ON ITVAR.CDPRECBASESERV  = TIPO.CDPRECBASESERV
                  AND ITVAR.NRORG          = TIPO.NRORG
                  AND TIPO.NRTIPOORCAMENTO = REFE.NRTIPOORCAMENTO
                INNER JOIN FCT_ITESCOPOPROPOSTA ITESC
                  ON TIPO.NRTIPOORCAMENTO = ITESC.NRTIPOORCAMENTO
                  AND TIPO.NRORG          = ITESC.NRORG
                  AND TRAB.CDSERVORCA     = ITESC.CDSERVORCA
                LEFT JOIN FCT_RELACMEDIDACONTRATO REL
                  ON TRAB.NRSEQCONTRATO   = REL.NRSEQCONTRATO
                  AND TRAB.NRORG          = REL.NRORG
                LEFT JOIN FCT_VARIACAOPRECBASESERV VAR
                  ON ITVAR.NRSEQITPRECBSERV  = VAR.NRSEQITPRECBSERV
                  AND ITVAR.NRORG            = VAR.NRORG
                  AND REL.CDTPMEDIDAVARIAVEL = VAR.CDTPMEDIDAVARIAVEL
                INNER JOIN FCT_RELACSERVICO RELACSERV
                  ON ITVAR.CDSERVORCA = RELACSERV.CDSERVORCARELAC
                  AND ITVAR.NRORG     = RELACSERV.NRORG
                WHERE TRAB.NRSEQCONTRATO = :NRSEQCONTRATO
                  AND TRAB.NRORG         = :NRORG
                  AND (CONT.NRVERSAOCONTRATO > 1
                        OR (SELECT COUNT(*) 
                            FROM FCT_VARPRECBASESERVORCA
                            WHERE NRSEQORCAMENTO = REFE.NRSEQORCAMENTO
                              AND NRORG          = REFE.NRORG) = 0)";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    /**
     * Insere as variações de preço ligadas ao contrato na 
     * tabela de relacionamento entre contrato e variação
    **/
    public function inserirDadosVariacaoPrecoBaseContrato(array $params) {
        $sql = "INSERT INTO FCT_VARPRECBASESERVCONT (
                    NRVARPRECBASESERVCONT, NRSEQCONTRATO,      CDSERVORCA,
                    CDTPMEDIDASERV,        CDTPMEDIDAVARIAVEL, QTMEDIDAINIVARIACAO,
                    QTMEDIDAFIMVARIACAO,   QTFRANQUIA,         VRPRECOVARIACAO,
                    IDMULTIPVARIACAO,      NRORG,              IDATIVO,
                    DTINCLUSAO,            NRORGINCLUSAO,      CDOPERINCLUSAO,
                    DTULTATU,              NRORGULTATU,        CDOPERULTATU
                ) VALUES (
                    :NRVARPRECBASESERVCONT, :NRSEQCONTRATO,      :CDSERVORCA,
                    :CDTPMEDIDASERV,        :CDTPMEDIDAVARIAVEL, :QTMEDIDAINIVARIACAO,
                    :QTMEDIDAFIMVARIACAO,   :QTFRANQUIA,         ROUND(:VRPRECOVARIACAO, 2),
                    :IDMULTIPVARIACAO,      :NRORG,              :IDATIVO,
                    SYSDATE,                :NRORGINCLUSAO,      :CDOPERINCLUSAO,
                    NULL,                   NULL,                NULL
                )";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    /**
     * Retorna informações dos elementos de uma proposta
    **/
    public function getElementosProposta(array $params) {
        $sql = "SELECT NRTIPOORCAMENTO,
                  NRCOMPSERVICO,
                  NRCOMPSERVICO,
                  IDELEMENTO,
                  IDELEMENTOPAI,
                  IDTIPOELEMENTO,
                  IDESCOLHIDO,
                  CDSERVORCA AS CDSERVORCARELAC,
                  CDTPMEDIDASERV AS CDTPMEDIDAVARIAVEL,
                  VRUNITSERVORCA AS VRPRECO,
                  IDSERVOBRIGCOMP,
                  QTMEDIDAVARIAVEL,
                  QTMEDSERVORCA AS QTMEDIDASERV,
                  IDTIPOELEMENTO AS IDTIPO
                FROM FCT_TRABSERVORCAMENTO 
                WHERE NRSEQORCAMENTO = :NRSEQORCAMENTO
                  AND NRORG          = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll(); 
    }
    /**
     * Retorna os itens de uma proposta
    **/
    public function getItensProposta(array $params, $idItensPai) {
        $sql = "SELECT NRITEMORCAMENTO,
                   NMITEMORCAMENTO AS NMSERVORCA,
                   CDSERVORCA,
                   NRTIPOORCAMENTO,
                   QTITEMORCAMENTO,
                   VRUNITITEMORCA,
                   VRTOTALITEMORCA,
                   QTMEDIDAORCA AS QTMEDIDASERV,
                   IDELEMENTO,
                   CDTPMEDIDAVARIAVEL,
                   NMCONTRATUALITEMORCA,
                   CDTPMEDIDASERV,
                   QTPARCELASFATU, 
                   NRDIAVENCPARCELASFATU,
                   DECODE(IDELEMENTO, NULL, 'I', 'M') AS IDTIPO
                FROM FCT_ITEMORCAMENTO
                WHERE NRSEQORCAMENTO    = :NRSEQORCAMENTO
                    AND NRORG           = :NRORG 
                    AND NRTIPOORCAMENTO = :NRTIPOORCAMENTO
                    AND IDELEMENTO $idItensPai";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll(); 
    }
    /**
     * A partir de um item do contrato, retorna o item de negociação equivalente na proposta 
    **/
    public function getItNegociacaoEquivalenteProposta(array $params) {
        $sql = "SELECT ITORC.NRNEGOCIACAOPROPOSTA,
                  ITORC.NRITNEGOCIACAOPROPOSTA,
                  ITORC.NRITEMORCAMENTO
                FROM FCT_ITNEGOCIACAOPROPOSTA ITORC
                JOIN FCT_ITEMCONTRATO ITCONT
                  ON ITORC.NRITEMORCAMENTO = ITCONT.NRITEMORCAMENTO
                  AND ITORC.NRORG          = ITCONT.NRORG
                WHERE ITCONT.NRITEMOCONTRATO = :NRITEMORCONTRATO
                  AND ITCONT.NRORG           = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll(); 
    }
    /**
     * Retorna as negociações de valores da proposta ligada ao contrato
    **/
    public function getNegociacaoProposta(array $params) {
        $sql = "SELECT REFE.NRSEQCONTRATO,
                  REFE.NRTIPOORCAMENTO,
                  NEGOORC.IDTPFATURA,
                  NEGOORC.CDFILIALFATURA,
                  NEGOORC.CDTIPOOPERFATURA,
                  NEGOORC.CDSERIENF,
                  NEGOORC.CDEMPRESA,
                  NEGOORC.CDINSCESTA,
                  NEGOORC.CDINSCMUNI,
                  NEGOORC.NRNEGOCIACAOPROPOSTA,
                  NEGOORC.NRPARCFATURA,
                  NEGOORC.VRDESCITEM,
                  NEGOORC.VRPERCDESCITEM
                FROM FCT_NEGOCIACAOPROPOSTA NEGOORC
                JOIN FCT_REFEORCACONT REFE
                  ON NEGOORC.NRSEQORCAMENTO   = REFE.NRSEQORCAMENTO
                  AND NEGOORC.NRTIPOORCAMENTO = REFE.NRTIPOORCAMENTO
                  AND NEGOORC.NRORG           = REFE.NRORG
                WHERE REFE.NRSEQCONTRATO   = :NRSEQCONTRATO
                  AND REFE.NRTIPOORCAMENTO = :NRTIPOORCAMENTO
                  AND REFE.NRORG           = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll(); 
    }
    /**
     * Retorna da proposta, os itens de uma determinada negociação 
    **/
    public function getItensNegociacaoProposta(array $params) {
        $sql = "SELECT ITCONT.NRITEMOCONTRATO,
                  ITCONT.NRITEMCONTRATOPAI,
                  ITORC.VRTOTITEM AS VRTOTITEMCONT,
                  ITORC.NRITEMORCAMENTO,
                  ITORC.CDSERVORCA,
                  ITORC.CDPRODFATURA,
                  ITORC.NRPARCFATURA,
                  ITORC.NRITNEGOCIACAOPROPOSTA
                FROM FCT_ITNEGOCIACAOPROPOSTA ITORC
                JOIN FCT_ITEMCONTRATO ITCONT
                  ON ITORC.NRITEMORCAMENTO = ITCONT.NRITEMORCAMENTO
                  AND ITORC.NRORG          = ITCONT.NRORG
                WHERE ITCONT.NRSEQCONTRATO       = :NRSEQCONTRATO
                  AND ITORC.NRNEGOCIACAOPROPOSTA = :NRNEGOCIACAOPROPOSTA
                  AND ITCONT.NRORG               = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll(); 
    }
    /**
     * Atualiza um registro do tipo de medida na tabela de relacionamento entre medida e proposta
    **/
    public function salvarTipoMedidaProposta(array $params) {
        $sql = "UPDATE FCT_RELACMEDIDAPROPOSTA
                SET QTMEDIDAVARIAVEL = :QTMEDIDAVARIAVEL,
                    CDOPERULTATU     = :CDOPERULTATU,
                    NRORGULTATU      = :NRORG
                WHERE NRSEQORCAMENTO       = :NRSEQORCAMENTO
                    AND CDTPMEDIDAVARIAVEL = :CDTPMEDIDAVARIAVEL
                    AND IDELEMENTORAIZ     = :IDELEMENTORAIZ
                    AND NRORG              = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function getSomaValorItensFilhosContrato(array $params) {
        $sql = "SELECT SUM(VRTOTITEMCONT) AS VRTOTAL
                  FROM FCT_ITEMCONTRATO
                 WHERE NRSEQCONTRATO     = :NRSEQCONTRATO
                   AND NRORG             = :NRORG
                   AND NRITEMCONTRATOPAI = :NRITEMCONTRATOPAI
                   AND IDADICITEMCONT    = 'N'";
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    /**
     * Busca a quantidade máxima de parcelas permitida a um operador
    **/
    public function getQuantidadeMaxParcelasOper(array $params) {
        $sql = "SELECT QTPARCMAXIMAOPER AS QTPARCMAXIMA
                FROM FCT_QTPARCMAXIMAOPER
                WHERE CDOPERADOR = :CDOPERADOR 
                  AND NRORG      = :NRORG";
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    /**
     * Busca a quantidade máxima de parcelas permitida a um perfil de acesso
    **/
    public function getQuantidadeMaxParcelasPerfil(array $params) {
        $sql = "SELECT MIN(QTPARCMAXPERFACESS) AS QTPARCMAXIMA
                FROM FCT_QTPARCMAXPERFACESS QTPARC
                JOIN PERFACESSPARC PERFIL
                  ON QTPARC.NRPERFILACESSO = PERFIL.NRPERFILACESSO
                  AND QTPARC.NRORG         = PERFIL.NRORG
                WHERE QTPARC.NRORG = :NRORG
                  AND PERFIL.NRPARCNEGOCIO IN(SELECT NRPARCNEGOCIO 
                                              FROM OPERADOR 
                                              WHERE CDOPERADOR = :CDOPERADOR 
                                                AND NRORG      = :NRORG)";
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    /**
     * Retorna as parcelas da negociação
    **/
    public function getParcelasNegociacao(array $params) {
        $sql = "SELECT NRPARCELANEGOPROP,
                    QTDIASFATURAMENTO,
                    NRPARCELA,
                    NRDIAVENCIMENTO,
                    VRPARCELA
                FROM FCT_PARCELANEGOCONT
                WHERE NRNEGOCIACAOCONTRATO = :NRNEGOCIACAOCONTRATO
                   AND NRORG               = :NRORG";
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    /**
     * Retorna a quantidade máxima de parcelas da 
     * tabela de parametro de faturamento dos itens do escopo 
     * (caso haja mais de um serviço será retornado a menor quantidade)
    **/
    public function getQtMaxParcelasItemEscopo(array $params) {
        $sql = "SELECT MIN(PA.QTPARCELASFATU) AS QTPARCELASFATU
                FROM FCT_PARAMFATITESC PA
                INNER JOIN FCT_ITESCOPOPROPOSTA IT
                  ON PA.NRITESCOPOPROPOSTA = IT.NRITESCOPOPROPOSTA
                  AND PA.NRORG             = IT.NRORG
                WHERE IT.NRTIPOORCAMENTO = :NRTIPOORCAMENTO 
                  AND IT.NRORG           = :NRORG
                  AND IT.CDSERVORCA IN(SELECT CDSERVORCA
                                        FROM FCT_ITNEGOCIACAOCONTRATO
                                        WHERE NRNEGOCIACAOCONTRATO = :NRNEGOCIACAOCONTRATO
                                          AND NRORG                = :NRORG)";
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    /**
     * Retorna a quantidade máxima de parcelas da 
     * tabela de parametro de faturamento dos itens do escopo 
     * (caso haja mais de um serviço será retornado a menor quantidade)
    **/
    public function getQtMaxParcelasEscopo(array $params) {
        $sql = "SELECT NVL(QTPARCELASFATU, 0) AS QTPARCELASFATU
                  FROM FCT_CAPAPARAMFATESC
                 WHERE NRTIPOORCAMENTO = :NRTIPOORCAMENTO 
                   AND NRORG           = :NRORG";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }

    public function getEscopoContrato(array $params) {
        $sql = "SELECT NVL(CONT.NRTIPOORCAMENTO, REFE.NRTIPOORCAMENTO) AS NRTIPOORCAMENTO
                  FROM FCT_CONTRATO CONT
                  LEFT JOIN FCT_REFEORCACONT REFE
                    ON CONT.NRSEQCONTRATO = REFE.NRSEQCONTRATO
                   AND CONT.NRORG         = REFE.NRORG
                 WHERE CONT.NRSEQCONTRATO = :NRSEQCONTRATO
                   AND CONT.NRORG         = :NRORG";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }

    /**
     * Retorna os elementos e o parceiro de negocio de um contrato
    **/
    public function getInformacoesContrato(array $params) {
        $sql = "SELECT DISTINCT IDELEMENTO,
                  CONT.NRPARCNEGOCIO
                FROM FCT_TRABSERVCONTRATO ELEMENTOS
                JOIN FCT_CONTRATO CONT 
                  ON ELEMENTOS.NRSEQCONTRATO = CONT.NRSEQCONTRATO
                  AND ELEMENTOS.NRORG        = CONT.NRORG
                WHERE ELEMENTOS.IDATIVO        = 'S'
                  AND ELEMENTOS.IDESCOLHIDO    = 'S'
                  AND ELEMENTOS.IDTIPOELEMENTO = 'P'
                  AND ELEMENTOS.NRSEQCONTRATO  = :NRSEQCONTRATO
                  AND ELEMENTOS.NRORG          = :NRORG";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    /**
     * Retorna o nrorg de um parceiro de negocio
    **/
    public function getNrorgParceiroDeNegocio(array $params){
        $sql = "SELECT NRORG
                FROM ORGANIZACAO
                WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO";
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();        
    }
    
    public function getValorNegociacaoComSomaParcelas(array $params) {
        $sql = "SELECT NEG.NRNEGOCIACAOCONTRATO,
                       NEG.VRTOTITEMCOMDESC,
                       (SELECT SUM(VRPARCELA)
                          FROM FCT_PARCELANEGOCONT
                         WHERE NRNEGOCIACAOCONTRATO = NEG.NRNEGOCIACAOCONTRATO
                           AND NRORG                = NEG.NRORG) AS SOMA_PARCELAS
                  FROM FCT_NEGOCIACAOCONTRATO NEG
                 WHERE NEG.NRSEQCONTRATO        = :NRSEQCONTRATO
                   AND NEG.NRNEGOCIACAOCONTRATO = :NRNEGOCIACAOCONTRATO
                   AND NEG.NRORG                = :NRORG
                   AND NEG.IDTPFATURA           = 'P'";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }

    /**
     * Retona os idelementos que serão desabilitados no OM
    **/
    public function getElementosParaDesabilitar(array $params) {
        $sql = "SELECT DISTINCT IDELEMENTO
                FROM (SELECT * 
                      FROM (SELECT DISTINCT IDELEMENTO, IDELEMENTOPAI, IDTIPOELEMENTO
                            FROM FCT_TRABSERVCONTRATO
                            WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                              AND NRORG         = :NRORG
                              AND IDESCOLHIDO   = 'S') ARVORE
                      WHERE IDELEMENTO NOT IN (SELECT DISTINCT TRAB.IDELEMENTO
                                                FROM FCT_TRABSERVCONTRATO TRAB
                                                INNER JOIN FCT_CONTRATO CONT
                                                  ON TRAB.NRSEQCONTRATO = CONT.NRSEQCONTRATO
                                                WHERE CONT.IDSITUACAOCONTRATO = 'A'
                                                  AND TRAB.IDESCOLHIDO        = 'S'
                                                  AND TRAB.IDELEMENTOPAI IS NOT NULL
                                                  AND CONT.NRSEQCONTRATO NOT IN (SELECT NRSEQCONTRATO
                                                                                   FROM FCT_REFEORCACONT
                                                                                  WHERE NRSEQORCAMENTO = (SELECT NRSEQORCAMENTO
                                                                                                            FROM FCT_REFEORCACONT
                                                                                                           WHERE NRSEQCONTRATO = :NRSEQCONTRATO))
                                                  AND CONT.NRPARCNEGOCIO = :NRPARCNEGOCIO)
                      CONNECT BY PRIOR ARVORE.IDELEMENTO = ARVORE.IDELEMENTOPAI
                      START WITH ARVORE.IDELEMENTOPAI = :IDELEMENTOPAI)
                WHERE IDTIPOELEMENTO = 'M'";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }

    public function reajustarParcelasNegociacao(array $params) {
        $sql = "UPDATE FCT_PARCELANEGOCONT
                   SET VRPARCELA = VRPARCELA + (VRPARCELA * :VRPERCENTUAL / 100),
                       DTULTATU       = SYSDATE,
                       NRORGULTATU    = :NRORGULTATU,
                       CDOPERULTATU   = :CDOPERULTATU
                 WHERE NRNEGOCIACAOCONTRATO = :NRNEGOCIACAOCONTRATO
                   AND NRORG                = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }

    public function getNegociacoesContrato(array $params) {
        $sql = "SELECT NRNEGOCIACAOCONTRATO, VRTOTITEMCOMDESC
                  FROM FCT_NEGOCIACAOCONTRATO
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG         = :NRORG";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }

    public function excluirNegociacaoContrato(array $params) {
        $sql = "DELETE FROM FCT_NEGOCIACAOCONTRATO
                 WHERE NRNEGOCIACAOCONTRATO = :NRNEGOCIACAOCONTRATO
                   AND NRORG                = :NRORG";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }

    public function getCodigoNegociacaoDoItem(array $params) {
        $sql = "SELECT NRNEGOCIACAOCONTRATO
                  FROM FCT_ITNEGOCIACAOCONTRATO
                 WHERE NRITEMOCONTRATO = :NRITEMOCONTRATO
                   AND NRORG           = :NRORG";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    /**
     * Atualiza o nome contratual do item
    **/
    public function atualizarNomeContratualItens($params){
        $sql = "UPDATE FCT_ITEMCONTRATO
                SET NMCONTRATUALITEMCONT = :NMCONTRATUALITEMCONT
                WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                    AND NRORG       = :NRORG
                    AND IDELEMENTO  = :IDELEMENTO";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function getValorVariacoesPrecoContrato(array $params) {
        $sql = "SELECT COUNT(*) QTMEDIDAS
                FROM FCT_VARPRECBASESERVCONT
                WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                  AND NRORG         = :NRORG";
    
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getParametrosFaturaNegociacoesContrato(array $params) {
        $sql = "SELECT NEG.NRNEGOCIACAOCONTRATO,
                     NEG.IDTPFATURA,
                     NEG.CDFILIALFATURA,
                     NEG.CDTIPOOPERFATURA,
                     NEG.CDSERIENF,
                     VRPERCDESCITEM,
                     VRDESCITEM,
                     (SELECT SUM(VRPARCELA)
                      FROM FCT_PARCELANEGOCONT
                      WHERE NRNEGOCIACAOCONTRATO = NEG.NRNEGOCIACAOCONTRATO
                        AND NRORG                = NEG.NRORG) AS SOMA_PARCELAS
                FROM FCT_NEGOCIACAOCONTRATO NEG
                WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                  AND NRORG         = :NRORG";
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }

    /* Retorna as datas do contrato para montar as datas da query "validaReajuste"
     */
    public function getDatasContr(array $params) {
        $sql = "SELECT NRSEQCONTRATO, DTINICIOCONTRATO, DTFIMCONTRATO, 
                       DTINIVIGENCONT, DTFINVIGENCONT 
                  FROM FCT_CONTRATO
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
     /* Verifica se foi realizado um reajuste de contrato dentro do período 
     */
    public function validaReajuste(array $params) {
        $sql = "SELECT COUNT(*) AS VALIDA 
                  FROM FCT_CONTRATOREAJUSTE
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND TRUNC(DTINCLUSAO) BETWEEN ADD_MONTHS(:DTINICIO, -1) AND :DTFINAL
                   AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Retorna todos os descontos da negociação e seus itens
    **/
    public function getDescontosNegociacaoValores(array $params) {
        $sql = "SELECT DISTINCT *
                FROM (
                    SELECT NEGO.NRTIPOORCAMENTO,
                      NEGO.NRSEQCONTRATO,
                      NEGO.NRNEGOCIACAOCONTRATO,
                      NEGO.NRORG,
                      DECODE(NVL(NEGO.VRPERCDESCITEM, 0), 0, ITNEGO.IDTPDESCONTO, NEGO.IDTPDESCONTO) AS IDTPDESCONTO, 
                      DECODE(NVL(NEGO.VRPERCDESCITEM, 0), 0, NVL(ITNEGO.VRPERCDESCITEM, 0), NVL(NEGO.VRPERCDESCITEM, 0)) AS VRPERCDESCITEM,
                      DECODE(NVL(NEGO.VRPERCDESCITEM, 0), 0, NVL(ITNEGO.VRDESCITEM, 0), NVL(NEGO.VRDESCITEM, 0)) AS VRDESCITEM,
                      DECODE(NVL(NEGO.VRPERCDESCITEM, 0), 0, 'ITENS', 'NEGOCIACAO') AS TIPODESCONTO,
                      DECODE(NVL(NEGO.VRPERCDESCITEM, 0), 0, ITNEGO.CDSERVORCA, NULL) CDSERVORCA,
                      DECODE(NVL(NEGO.VRPERCDESCITEM, 0), 0, ITNEGO.NRITEMOCONTRATO, NULL) NRITEMOCONTRATO
                    FROM FCT_NEGOCIACAOCONTRATO NEGO
                    INNER JOIN FCT_ITNEGOCIACAOCONTRATO ITNEGO
                      ON NEGO.NRNEGOCIACAOCONTRATO = ITNEGO.NRNEGOCIACAOCONTRATO
                      AND NEGO.NRORG               = ITNEGO.NRORG
                ) DESCONTOS
                WHERE DESCONTOS.VRPERCDESCITEM       <> 0
                  AND DESCONTOS.NRNEGOCIACAOCONTRATO = :NRNEGOCIACAOCONTRATO
                  AND DESCONTOS.NRORG                = :NRORG";
                  
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    /**
     * insere um desconto por período
    **/
    public function inserirDescontoPorPeriodo(array $params) {
        $sql = "INSERT INTO FCT_DESCPERIODONEGOCONT (
                    NRDESCPERIODONEGOCONT, IDATIVO,       NRORG,
                    VRPERCDESCITEM,        VRDESCITEM,    VRTOTITEMCOMDESC,
                    NRNEGOCIACAOCONTRATO,  QTMESESDESC,   DTFINALVALIDADEDESC,
                    DTINCLUSAO,            NRORGINCLUSAO, CDOPERINCLUSAO,
                    DTULTATU,              NRORGULTATU,   CDOPERULTATU,
                    NRORDEMAPLICADESC,     IDTPDESCONTO
                ) VALUES (
                    :NRDESCPERIODONEGOCONT, :IDATIVO,       :NRORG,
                    :VRPERCDESCITEM,        :VRDESCITEM,    :VRTOTITEMCOMDESC,
                    :NRNEGOCIACAOCONTRATO,  :QTMESESDESC,   :DTFINALVALIDADEDESC,
                    :DTINCLUSAO,            :NRORGINCLUSAO, :CDOPERINCLUSAO,
                    :DTULTATU,              :NRORGULTATU,   :CDOPERULTATU,
                    :NRORDEMAPLICADESC,     :IDTPDESCONTO
                )";
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    /**
     * Retorna as parcelas das negociações de uma proposta
    **/
    public function getParcelasContrato(array $params) {
        $sql = "SELECT NRPARCELANEGOCONT,
                    QTDIASFATURAMENTO,
                    NRPARCELA,
                    NRDIAVENCIMENTO,
                    NRNEGOCIACAOCONTRATO,
                    VRPARCELA,
                    NRORG,
                    NRORGINCLUSAO,
                    CDOPERINCLUSAO
                FROM FCT_PARCELANEGOCONT
                WHERE NRNEGOCIACAOCONTRATO IN (SELECT NRNEGOCIACAOCONTRATO
                                               FROM FCT_NEGOCIACAOCONTRATO
                                               WHERE NRSEQCONTRATO  = :NRSEQCONTRATO
                                                    AND NRORG       = :NRORG)";
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    /**
     * Retorna o nritemorcamento de um item segundo as informações do elemento, serviço e medida
    **/
    public function getNovoItemCorrespondente(array $params) {
        $sql = "SELECT NRITEMOCONTRATO, NRITEMCONTRATOPAI, QTMEDIDACALCULADA
                FROM FCT_ITEMCONTRATO
                WHERE IDELEMENTO         = :IDELEMENTO
                  AND CDSERVORCA         = :CDSERVORCA
                  AND CDTPMEDIDAVARIAVEL = :CDTPMEDIDAVARIAVEL
                  AND NRSEQCONTRATO      = :NRSEQCONTRATO
                  AND NRORG              = :NRORG";
                  
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getIdMultiplicavariacaoItem(array $params) {
        $sql = "SELECT NVL(VAR.IDMULTIPVARIACAO, 'S') AS IDMULTIPVARIACAO,
                  DECODE(VAR.VRPRECOVARIACAO, NULL, ITVAR.VRPRECO, VAR.VRPRECOVARIACAO) AS VRPRECOVARIACAO
                FROM FCT_ITPRECBASESERV ITVAR
                LEFT JOIN FCT_VARIACAOPRECBASESERV VAR
                  ON VAR.NRSEQITPRECBSERV  = ITVAR.NRSEQITPRECBSERV
                  AND VAR.NRORG            = ITVAR.NRORG
                WHERE ITVAR.NRORG          = :NRORG
                  AND ITVAR.CDSERVORCA     = :CDSERVORCA
                  AND ITVAR.CDTPMEDIDASERV = :CDTPMEDIDASERV
                  AND (VAR.IDMULTIPVARIACAO IS NULL
                      OR VAR.CDTPMEDIDAVARIAVEL = :CDTPMEDIDAVARIAVEL 
                      AND :QTMEDIDACONTR BETWEEN QTMEDIDAINIVARIACAO AND QTMEDIDAFIMVARIACAO)";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    /**
     * Retorna os dados da tabela de preço ligados a medida de um serviço 
    **/
    public function getSomatorioMedidaServico(array $params) {
        $sql = "SELECT SUM(RELACSERV.QTMEDIDASERV) AS QTMEDIDASERV
                  FROM FCT_RELACSERVICO RELACSERV
                 INNER JOIN FCT_SERVICOORCA SERV
                    ON RELACSERV.CDSERVORCA = SERV.CDSERVORCA
                   AND RELACSERV.NRORG     = SERV.NRORG
                 INNER JOIN (SELECT IDELEMENTO
                               FROM (SELECT DISTINCT IDELEMENTO, IDELEMENTOPAI
                                       FROM FCT_TRABSERVCONTRATO
                                      WHERE NRSEQCONTRATO  = :NRSEQCONTRATO
                                        AND NRORG          = :NRORG
                                        AND IDESCOLHIDO    = 'S'
                                        AND IDATIVO        = 'S')
                            CONNECT BY PRIOR IDELEMENTO = IDELEMENTOPAI
                              START WITH IDELEMENTO     = :IDELEMENTO) TRAB
                    ON SERV.IDELEMENTO = TRAB.IDELEMENTO
                 WHERE RELACSERV.CDSERVORCARELAC = :CDSERVORCA
                   AND RELACSERV.NRORG           = :NRORG";
                      
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    /**
     * Atualiza o valor de um item
    **/
    public function atualizarValorItensOrcamento(array $params){
        $sql = "UPDATE FCT_ITEMCONTRATO
                SET VRUNITITEMCONT         = :VRUNITITEMCONT,
                    VRTOTITEMCONT          = :VRTOTITEMCONT,
                    VRUNITITEMCONTTBLPRECO = :VRUNITITEMCONTTBLPRECO,
                    QTMEDIDACONTR          = :QTMEDIDACONTR
                WHERE NRITEMOCONTRATO = :NRITEMOCONTRATO
                    AND NRORG         = :NRORG";
                    
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * Retorna o somatorio do elementos de um determinado servico
    **/
    public function getValorTotalItensTipoElemento(array $params){
        $sql = "SELECT SUM(VRTOTITEMCONT) AS VRTOTITEMCONT
                FROM FCT_ITEMCONTRATO
                WHERE NRSEQCONTRATO  = :NRSEQCONTRATO
                    AND CDSERVORCA   = :CDSERVORCA
                    AND NRORG        = :NRORG
                    AND IDELEMENTO IS NOT NULL";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll()[0]["VRTOTITEMCONT"];
    }
    
    /**
     * Altera o valor total do item após as alterações no valor de um elemento
    **/
    public function atualizarValorItemPai(array $params){
        $vrtotitemcont = $this->getValorTotalItensTipoElemento($params);
        $sql = "UPDATE FCT_ITEMCONTRATO
                SET VRUNITITEMCONT   = $vrtotitemcont,
                    VRTOTITEMCONT    = $vrtotitemcont
                WHERE NRSEQCONTRATO  = :NRSEQCONTRATO
                    AND CDSERVORCA   = :CDSERVORCA
                    AND NRORG        = :NRORG
                    AND IDELEMENTO IS NULL";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * Retorna os dados de uma negociacao a partir das informações de faturamento
     * fornecidas
    **/
    public function getNovaNegociacaoCorrespondente(array $params) {
        $sql = "SELECT NEG.NRNEGOCIACAOCONTRATO,
                       NEG.VRTOTITEMCOMDESC,
                       (SELECT SUM(VRPARCELA)
                        FROM FCT_PARCELANEGOCONT
                        WHERE NRNEGOCIACAOCONTRATO = NEG.NRNEGOCIACAOCONTRATO
                            AND NRORG              = NEG.NRORG) AS SOMA_PARCELAS
                FROM FCT_NEGOCIACAOCONTRATO NEG
                WHERE NEG.NRSEQCONTRATO     = :NRSEQCONTRATO
                  AND NEG.IDTPFATURA        = :IDTPFATURA
                  AND NEG.CDSERIENF         = :CDSERIENF
                  AND NEG.CDTIPOOPERFATURA  = :CDTIPOOPERFATURA
                  AND NEG.CDFILIALFATURA    = :CDFILIALFATURA
                  AND NEG.NRORG             = :NRORG";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    /**
     * Atualiza o valor dos itens da negociação 
    **/
    public function atualizarItensNegociaco(array $params, $sqlAux) {
        $sql = "UPDATE FCT_ITNEGOCIACAOCONTRATO
                SET $sqlAux
                WHERE NRNEGOCIACAOCONTRATO = :NRNEGOCIACAOCONTRATO
                    AND NRITEMOCONTRATO    = :NRITEMOCONTRATO
                    AND NRORG              = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    /**
     * Atualiza o valor da negociação 
    **/
    public function atualizarNegociaco(array $params, $sqlAux) {
        $sql = "UPDATE FCT_NEGOCIACAOCONTRATO
                SET $sqlAux
                WHERE NRNEGOCIACAOCONTRATO = :NRNEGOCIACAOCONTRATO
                    AND NRORG              = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    /**
     * A função "validaPercentual" valida o percentual para inserção na página "índices Financeiros Padrões"
     */
    
    public function validaPercentual(array $params){
        $sql = "SELECT SUM(NRPERCENTINDICE) AS TOTPERCENT 
                  FROM FCT_INDICESPADRCONTR
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG         = :NRORG
                   AND (CDINDICE <> :CDINDICE OR :CDINDICE IS NULL)";
                 
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
     /**
     * A função "indicesParcNegocio" recebe os dados da página "índices Financeiros Padrões" da tela "Parceiro de Negócio"
     */
    
    public function indicesParcNegocio(array $params){
        $sql = "SELECT NRINDICESPADRPARC, CDTPINDICE, IDPERVALOR, CDINDICE, NRPERCENTINDICE
                  FROM FCT_INDICESPADRPARC
                 WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO
                   AND NRORG = :NRORG";
                 
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
     /**
     * A função "indicesEscopo" recebe os dados da página "índices Financeiros Padrões" da tela "Escopo de Faturamento"
     */
    
    public function indicesEscopo(array $params){
        $sql = "SELECT NRINDICESPADRESCOPO, CDTPINDICE, IDPERVALOR, CDINDICE, NRPERCENTINDICE
                  FROM FCT_INDICESPADRESCOPO
                 WHERE NRTIPOORCAMENTO = :NRTIPOORCAMENTO
                   AND NRORG = :NRORG";
                 
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    
     /**
     * A função "insereIndicesPadroes" insere os indices padrões que já estiverem preenchidos para o Parceiro de negócio ou para o escopo de faturamento, com prioridade para o parceiro de negócio.
     */
    
    public function insereIndicesPadroes(array $params){
        $sql = "INSERT INTO FCT_INDICESPADRCONTR (NRINDICESPADRCONTR, NRSEQCONTRATO, CDTPINDICE, IDPERVALOR, CDINDICE, NRPERCENTINDICE,
                                                  IDATIVO, NRORG, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO)
                        VALUES (:NRINDICESPADRCONTR, :NRSEQCONTRATO, :CDTPINDICE, :IDPERVALOR, :CDINDICE, :NRPERCENTINDICE,
                                'S', :NRORG, SYSDATE, :NRORG, :OPERADOR)";
                 
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function validaReajusteFatu(array $params) {
        $sql = "SELECT IDBLOQAPURFATSEMREAJ
                  FROM FCT_PARAMETROGERAL
                 WHERE NRORG = :NRORG";
                   
        $ps = $this->connection->prepare($sql);
        $ps->execute($params); 
        return $ps->fetchAll();
    }
    
    /**
     * Valida se há contratos reajustados automaticamente ou contratos vencidos para uma 
     * determinada data
     */
    public function validarExistenciaRenovacaoAutomatica(array $params) {
        $sql = "SELECT CONT.NRSEQCONTRATO
                FROM FCT_CONTRATO CONT 
                WHERE NRORG = :NRORG
                   AND (TRUNC(DTRENOVACAO)           = SYSDATE
                    OR (CONT.IDRENOVACAOAUTOMATICA   = 'N' 
                        AND TRUNC(DTFINVIGENCONT)    = :DTREFERENCIA))";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params); 
        return $ps->fetchAll();
    }
    
    public function inserirMedidaVariavelServico(array $params) {
        $sql = "INSERT INTO FCT_RELACMEDIDACONTRATO (
            NRMEDIDACONTRATO,  NRSEQCONTRATO,   CDTPMEDIDAVARIAVEL,
            QTMEDIDAVARIAVEL,  NRORG,           DTINCLUSAO,
            NRORGINCLUSAO,     CDOPERINCLUSAO,  IDATIVO,
            IDELEMENTORAIZ,    QTFRANQUIA,      CDSERVORCA,
            NRTIPOORCAMENTO
        )
        VALUES (
            :NRMEDIDACONTRATO,  :NRSEQCONTRATO,   :CDTPMEDIDAVARIAVEL,
            :QTMEDIDAVARIAVEL,  :NRORG,           SYSDATE,
            :NRORGINCLUSAO,     :CDOPERINCLUSAO,  :IDATIVO,
            :IDELEMENTORAIZ,    :QTFRANQUIA,      :CDSERVORCA,
            :NRTIPOORCAMENTO
        )";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }

    public function getMedidaVariavelServicoContrato(array $params) {
        $sql = "SELECT NRMEDIDACONTRATO, QTMEDIDAVARIAVEL
                  FROM FCT_RELACMEDIDACONTRATO
                 WHERE NRSEQCONTRATO      = :NRSEQCONTRATO
                   AND CDTPMEDIDAVARIAVEL = :CDTPMEDIDAVARIAVEL
                   AND IDELEMENTORAIZ     IS NULL
                   AND CDSERVORCA         = :CDSERVORCA
                   AND NRORG              = :NRORG";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }

    public function atualizarMedidaVariavelServico(array $params) {
        $sql = "UPDATE FCT_RELACMEDIDACONTRATO
                   SET QTMEDIDAVARIAVEL = :QTMEDIDAVARIAVEL,
                       DTULTATU         = SYSDATE,
                       NRORGULTATU      = :NRORGULTATU,
                       CDOPERULTATU     = :CDOPERULTATU
                 WHERE NRMEDIDACONTRATO = :NRMEDIDACONTRATO
                   AND NRORG            = :NRORG";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function getMedidasVariaveisDosServicosProposta(array $params) {
        $sql = "SELECT CDTPMEDIDAVARIAVEL,
                       QTMEDIDAVARIAVEL AS QTMEDIDACONTR,
                       CDSERVORCA
                  FROM FCT_RELACMEDIDAPROPOSTA
                 WHERE NRSEQORCAMENTO  = :NRSEQORCAMENTO
                   AND NRTIPOORCAMENTO = :NRTIPOORCAMENTO
                   AND NRORG           = :NRORG
                   AND CDSERVORCA IS NOT NULL";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getSomaQuantidadeMedidaServicoContrato(array $params) {
        $sql = "SELECT SUM(QTMEDIDACONTR) AS QTMEDIDACONTR
                  FROM FCT_ITEMCONTRATO
                 WHERE NRSEQCONTRATO      = :NRSEQCONTRATO
                   AND CDSERVORCA         = :CDSERVORCA
                   AND NRORG              = :NRORG
                   AND NRITEMCONTRATOPAI IS NOT NULL";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getMedidasDeServicosDosContratos(array $params) {
        $sql = "SELECT LISTAGG(CDTPMEDIDAVARIAVEL, ', ') WITHIN GROUP (ORDER BY CDTPMEDIDAVARIAVEL) AS CDTPMEDIDAVARIAVEL,
                       LISTAGG(CDSERVORCA, ', ') WITHIN GROUP (ORDER BY CDSERVORCA) AS CDSERVORCA
                  FROM FCT_RELACMEDIDACONTRATO
                 WHERE NRSEQCONTRATO      = :NRSEQCONTRATO
                   AND NRORG              = :NRORG
                   AND IDELEMENTORAIZ     IS NULL";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }

    public function getVariacaoPresoBaseServicos(array $params) {
        $sql = "SELECT NVL(VARPREC.DTINIPBSERV, ITPREC.DTINIPBSERV) AS DTINIPBSERV,
                       NVL(VARPREC.CDTPMEDIDASERV, NVL(ITPREC.CDTPMEDIDASERV, ITCONT.CDTPMEDIDASERV)) AS CDTPMEDIDASERV,
                       NVL(RELMED.CDTPMEDIDAVARIAVEL, VARPREC.CDTPMEDIDAVARIAVEL) AS CDTPMEDIDAVARIAVEL,
                       NVL(VARPREC.QTMEDIDAINIVARIACAO, 0) AS QTMEDIDAINIVARIACAO,
                       NVL(VARPREC.QTMEDIDAFIMVARIACAO, 99999999) AS QTMEDIDAFIMVARIACAO,
                       NVL(VARPREC.VRPRECOVARIACAO, NVL(ITPREC.VRPRECO, NVL(ITCONT.VRUNITITEMCONTTBLPRECO, ITCONT.VRUNITITEMCONT))) AS VRPRECOVARIACAO,
                       NVL(VARPREC.DTFIMVALPBSERV, ITPREC.DTFIMVALPBSERV) AS DTFIMVALPBSERV,
                       NVL(VARPREC.IDMULTIPVARIACAO, 'N') AS IDMULTIPVARIACAO,
                       RELMED.CDSERVORCA,
                       VARPREC.QTFRANQUIA
                  FROM FCT_RELACMEDIDACONTRATO RELMED
                 INNER JOIN FCT_TIPOORCAMENTO ESC
                    ON RELMED.NRTIPOORCAMENTO = ESC.NRTIPOORCAMENTO
                   AND RELMED.NRORG           = ESC.NRORG
                 INNER JOIN FCT_ITEMCONTRATO ITCONT
                    ON RELMED.NRSEQCONTRATO = ITCONT.NRSEQCONTRATO
                   AND RELMED.NRORG         = ITCONT.NRORG
                   AND RELMED.CDSERVORCA    = ITCONT.CDSERVORCA
                  LEFT JOIN FCT_PRECBASESERV PREC
                    ON ESC.CDPRECBASESERV = PREC.CDPRECBASESERV
                   AND ESC.NRORG          = PREC.NRORG
                  LEFT JOIN FCT_ITPRECBASESERV ITPREC
                    ON RELMED.CDSERVORCA   = ITPREC.CDSERVORCA
                   AND RELMED.NRORG        = ITPREC.NRORG
                   AND PREC.CDPRECBASESERV = PREC.CDPRECBASESERV
                  LEFT JOIN FCT_VARIACAOPRECBASESERV VARPREC
                    ON ITPREC.NRSEQITPRECBSERV    = VARPREC.NRSEQITPRECBSERV
                   AND ITPREC.NRORG               = VARPREC.NRORG
                   AND RELMED.CDTPMEDIDAVARIAVEL  = VARPREC.CDTPMEDIDAVARIAVEL
                 WHERE RELMED.NRSEQCONTRATO     = :NRSEQCONTRATO
                   AND RELMED.NRORG             = :NRORG
                   AND ITCONT.NRITEMCONTRATOPAI IS NULL";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    /**
     * Valida se o operador tem acesso à página "Alterações Contratuais"
    **/
    public function validaAlteracoesContratuais(array $params) {
        $sql = "SELECT PERFACESSPARC.NRPERFACESSPARC, PERFACESSPARC.NRPARCNEGOCIO, OPERADOR.CDOPERADOR
                  FROM PERFACESSPARC
                  JOIN OPERADOR 
                    ON OPERADOR.NRPARCNEGOCIO = PERFACESSPARC.NRPARCNEGOCIO
                   AND OPERADOR.NRORG = PERFACESSPARC.NRORG
                 WHERE PERFACESSPARC.NRPERFILACESSO IN (SELECT NRPERFILACESSO 
                                                          FROM FCT_ALTCONTRAPROVPERF)
                   AND PERFACESSPARC.NRORG = :NRORG";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    /**
     *recebe os dados de "Alterações Contratuais"
    **/
    public function getAlteracaoContratual(array $params) {
        $sql = "SELECT DSALTERACONTRATUAIS
                  FROM FCT_CONTRATO
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG = :NRORG";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    /**
     * valida se o Token do Certsign está preenchido
    **/
    public function validaTokenCertsign(array $params) {
        $sql = "SELECT DSTOKENCERTSIGN 
                  FROM FCT_PARAMETROGERAL
                 WHERE NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Busca os signatários padrões do modelo de contrato 
    **/
    public function buscaSignatariosPadroes(array $params) {
        $sql = "SELECT FCT_SIGNATPADRMODCONT.NRSIGNATPADRCONT, FCT_SIGNATPADRMODCONT.NRSEQMODCONTRA, FCT_SIGNATPADRMODCONT.NRPARCNEGOCIO, 
                       PARCNEGOCIO.NRINSCRICAOPARC, FCT_SIGNATPADRMODCONT.IDTIPOASSINATURA, FCT_SIGNATPADRMODCONT.IDTESTEMUNHA, 
                       FCT_SIGNATPADRMODCONT.NRORDENACAO, FCT_SIGNATPADRMODCONT.NRORG 
                  FROM FCT_SIGNATPADRMODCONT
                  JOIN PARCNEGOCIO 
                    ON PARCNEGOCIO.NRPARCNEGOCIO = FCT_SIGNATPADRMODCONT.NRPARCNEGOCIO
                    AND PARCNEGOCIO.NRORG = FCT_SIGNATPADRMODCONT.NRORG
                  WHERE FCT_SIGNATPADRMODCONT.NRSEQMODCONTRA = :NRSEQMODCONTRA
                    AND FCT_SIGNATPADRMODCONT.NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    
    /**
     * insere os signatários padrões do modelo de contrato 
    **/
    public function insereAssinatura(array $params) {
        
        $sql = "INSERT INTO FCT_ASSINATDIGITALCONTR (NRASSDIGITALCONTR, NRSEQCONTRATO, NRPARCNEGOCIO, NRSEQINTERLOCUTOR, NRCPFSIGNATARIO, IDTIPOASSINATURA, IDTESTEMUNHA,
                                                    NRORDENACAO, NRORG, DTINCLUSAO, CDOPERINCLUSAO, NRORGINCLUSAO, IDATIVO)
                              VALUES (:NRASSDIGITALCONTR, :NRSEQCONTRATO, :NRPARCNEGOCIO, :NRSEQINTERLOCUTOR, :NRCPFSIGNATARIO, :IDTIPOASSINATURA, :IDTESTEMUNHA, 
                                      :NRORDENACAO, :NRORG, SYSDATE, :OPERADOR, :NRORG, 'S')";
                             
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * A função "validaSignatCadastrados" realiza a validação dos signatários padrões para evitar a inclusão repetida de um parceiro.
     */
    public function validaSignatCadastrados(array $params) {
        
        $sql = "SELECT COUNT (*) AS VALIDA
                  FROM FCT_ASSINATDIGITALCONTR
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO 
                   AND ((NRPARCNEGOCIO = :NRPARCNEGOCIO) OR (NRPARCNEGOCIO IS NULL))
                   AND ((NRSEQINTERLOCUTOR = :NRSEQINTERLOCUTOR) OR (NRSEQINTERLOCUTOR IS NULL)) 
                   AND NRORG = :NRORG
                   AND NRASSDIGITALCONTR <> NVL(:NRASSDIGITALCONTR, -1)";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $retorno = $std->fetchAll();
        return $retorno[0]["VALIDA"];
    }
    
    /**
     * A função "recebeIdAssEletrDigital" verifica se a proposta está apta para assinatura eletronica / digital
     */
    public function recebeIdAssEletrDigital(array $params) {
        
        $sql = "SELECT IDASSELETRDIGITAL 
                  FROM FCT_CONTRATO
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * A função "updateSituacaoAssManualParc" atualiza o signatario de parceiro de negócio como 
     * "Assinado Manualmente"
     */
    public function updateSituacaoAssManualParc(array $params) {
        
        $sql = "UPDATE FCT_ASSINATDIGITALCONTR
                   SET IDSITUACAO = 'M',
                       DTULTATU = SYSDATE, 
                       CDOPERULTATU = :OPERADOR, 
                       NRORGULTATU = :NRORG
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRPARCNEGOCIO = :NRPARCNEGOCIO
                   AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * A função "updateSituacaoAssManualInte" atualiza o signatario de interlocutor como 
     * "Assinado Manualmente" 
     */
    public function updateSituacaoAssManualInte(array $params) {
        
        $sql = "UPDATE FCT_ASSINATDIGITALCONTR
                   SET IDSITUACAO = 'M',
                       DTULTATU = SYSDATE, 
                       CDOPERULTATU = :OPERADOR, 
                       NRORGULTATU = :NRORG
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRSEQINTERLOCUTOR = :NRSEQINTERLOCUTOR
                   AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
     /**
     * A função "recebeassinaturas" recebe as assinaturas do contrato
     */
    public function recebeassinaturas(array $params) {
        
        $sql = "SELECT NRASSDIGITALCONTR, NRSEQCONTRATO, NRPARCNEGOCIO, NRCPFSIGNATARIO, IDTIPOASSINATURA, 
                	   IDTESTEMUNHA, NRORDENACAO, IDSITUACAO, NRORG
                  FROM FCT_ASSINATDIGITALCONTR
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * realiza o update da proposta para incluir / alterar o campo "DSALTERACONTRATUAIS"
    **/
    public function updateDsAlteracoesContr(array $params) {
        $sql = "UPDATE FCT_CONTRATO
                   SET DSALTERACONTRATUAIS = :DSALTERACONTRATUAIS,
                       DTULTATU = SYSDATE,
                       CDOPERULTATU = :OPERADOR,
                       NRORGULTATU = :NRORG
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG = :NRORG";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    /**
     * A função "getDadosSender" recebe os dados de responsável pelo envio do documento
     */
    public function getDadosSender(array $params) {
        
        $sql = "SELECT NMSENDERCERTSIGN, DSEMAILSENDERCERTSIGN, NRCPFSENDERCERTSIGN, IDPADRAOASSINACERTSIGN, NRTIPODOCCERTSIGN
                  FROM FCT_PARAMETROGERAL 
                 WHERE NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * A função "getSignatarios" recebe os dados dos signatários para o envio do documento
     */
    public function getSignatarios(array $params) {
        
        $sql = "SELECT FCT_ASSINATDIGITALCONTR.NRASSDIGITALCONTR, FCT_ASSINATDIGITALCONTR.NRSEQCONTRATO, FCT_ASSINATDIGITALCONTR.NRPARCNEGOCIO, 
                       FCT_ASSINATDIGITALCONTR.NRCPFSIGNATARIO, FCT_ASSINATDIGITALCONTR.IDTIPOASSINATURA, FCT_ASSINATDIGITALCONTR.IDTESTEMUNHA, 
                       FCT_ASSINATDIGITALCONTR.NRORDENACAO, FCT_ASSINATDIGITALCONTR.IDSITUACAO, FCT_ASSINATDIGITALCONTR.NRORG, 
                       FCT_ASSINATDIGITALCONTR.NRSEQINTERLOCUTOR, OPERADOR.NMOPERADOR AS NOME, OPERADOR.DSEMAILOPER AS EMAIL
                  FROM FCT_ASSINATDIGITALCONTR
                  JOIN OPERADOR 
                    ON OPERADOR.NRPARCNEGOCIO = FCT_ASSINATDIGITALCONTR.NRPARCNEGOCIO
                  AND OPERADOR.NRORG = FCT_ASSINATDIGITALCONTR.NRORG 
                 WHERE FCT_ASSINATDIGITALCONTR.NRSEQCONTRATO = :NRSEQCONTRATO
                   AND FCT_ASSINATDIGITALCONTR.IDTIPOASSINATURA = :IDTIPOASSINATURA
                   AND FCT_ASSINATDIGITALCONTR.NRORG = :NRORG
                    
                 UNION ALL
                 
                 SELECT FCT_ASSINATDIGITALCONTR.NRASSDIGITALCONTR, FCT_ASSINATDIGITALCONTR.NRSEQCONTRATO, FCT_ASSINATDIGITALCONTR.NRPARCNEGOCIO, 
                        FCT_ASSINATDIGITALCONTR.NRCPFSIGNATARIO, FCT_ASSINATDIGITALCONTR.IDTIPOASSINATURA, FCT_ASSINATDIGITALCONTR.IDTESTEMUNHA, 
                        FCT_ASSINATDIGITALCONTR.NRORDENACAO, FCT_ASSINATDIGITALCONTR.IDSITUACAO, FCT_ASSINATDIGITALCONTR.NRORG, 
                        FCT_ASSINATDIGITALCONTR.NRSEQINTERLOCUTOR, CRM_INTERLOCUTOR.NMINTERLOCUTOR AS NOME, CRM_INTERLOCUTOR.EMAILINTERLOC AS EMAIL
                  FROM FCT_ASSINATDIGITALCONTR
                  JOIN CRM_INTERLOCUTOR
                    ON CRM_INTERLOCUTOR.NRSEQINTERLOCUTOR = FCT_ASSINATDIGITALCONTR.NRSEQINTERLOCUTOR 
                   AND CRM_INTERLOCUTOR.NRORG = FCT_ASSINATDIGITALCONTR.NRORG
                 WHERE FCT_ASSINATDIGITALCONTR.NRSEQCONTRATO = :NRSEQCONTRATO
                   AND FCT_ASSINATDIGITALCONTR.IDTIPOASSINATURA = :IDTIPOASSINATURA
                   AND FCT_ASSINATDIGITALCONTR.NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
     /**
     * A função "getIdDocumentoCertsign" recebe os ids dos documentos do Certsign
     */
    public function getIdDocumentoCertsign(array $params) {
        
        $sql = "SELECT IDDOCUMCERTSIGN, CHAVEDOCUMCERTSIGN
                  FROM FCT_CONTRATODOC
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND ((IDSITUACAOCONTRATO IN ('A','D')) 
                    OR (IDSITUACAOCONTRATO IS NULL))
                   AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * A função "updateDocumentoIdCertsign" atualiza o registro dos documentos da proposta 
     * para incluir o ID e a Chave do Certsing" 
     */
    public function updateDocumentoIdCertsign(array $params) {
        
        $sql = "UPDATE FCT_CONTRATODOC
                   SET IDDOCUMCERTSIGN = :IDDOCUMCERTSIGN,
                       CHAVEDOCUMCERTSIGN = :CHAVEDOCUMCERTSIGN,
                       DTULTATU = SYSDATE,
                       CDOPERULTATU = :OPERADOR,
                       NRORGULTATU = :NRORG
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND ((IDSITUACAOCONTRATO IN ('A','D')) 
                    OR (IDSITUACAOCONTRATO IS NULL))
                   AND NRORG = :NRORG";
                    
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * A função "updateDocumentoIdCertsign" atualiza o registro dos signatários da proposta 
     * para incluir o ID do Certsing
     */
    public function updateSignatarioIdCertsign(array $params) {
        
        $sql = "UPDATE FCT_ASSINATDIGITALCONTR
                   SET IDSIGNATCERTSIGN = :IDSIGNATCERTSIGN,
                       DTULTATU = SYSDATE,
                       CDOPERULTATU = :OPERADOR,
                       NRORGULTATU = :NRORG
                 WHERE NRCPFSIGNATARIO = :NRCPFSIGNATARIO
                   AND NRORG = :NRORG";
                    
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * A função "updateSitContrDocEnv" atualiza o contrato para a situação
     * "Documento Enviado"
     */
    public function updateSitContrDocEnv(array $params) {
        
        $sql = "UPDATE FCT_CONTRATO
                   SET IDSITUACAOCONTRATO = 'D',
                       DTULTATU = SYSDATE,
                       CDOPERULTATU = :OPERADOR,
                       NRORGULTATU = :NRORG
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG = :NRORG";
                    
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function clearDocumentoIdCertsign(array $params) {
        
        $sql = "UPDATE FCT_CONTRATODOC
                   SET IDDOCUMCERTSIGN = NULL,
                       CHAVEDOCUMCERTSIGN = NULL,
                       DTULTATU = SYSDATE,
                       CDOPERULTATU = :OPERADOR,
                       NRORGULTATU = :NRORG
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND ((IDSITUACAOCONTRATO IN ('A','D')) 
                    OR (IDSITUACAOCONTRATO IS NULL))
                   AND NRORG = :NRORG";
                    
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function clearSignatarioIdCertsign(array $params) {
        
        $sql = "UPDATE FCT_ASSINATDIGITALCONTR
                   SET IDSIGNATCERTSIGN = NULL,
                       DTULTATU = SYSDATE,
                       CDOPERULTATU = :OPERADOR,
                       NRORGULTATU = :NRORG
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND ((NRCPFSIGNATARIO = :NRCPFSIGNATARIO)
                    OR ('T' = :NRCPFSIGNATARIO))
                   AND NRORG = :NRORG";
                    
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /* Recebe o sequencial do documento da assinatura*/
    public function recebeSeqDocumento (array $params){
    
        $sql = "SELECT NRSEQCONTDOC
                  FROM FCT_DOCASSINATCONTR
                 WHERE NRASSDIGITALCONTR = :NRASSDIGITALCONTR
                   AND NRSEQCONTRATO = :NRSEQCONTRATO
                   AND IDSITUACAO = 'P'
                   AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * A função "getIdDocumentoCertsign" recebe os ids dos documentos do Certsign
     */
    public function getIdDocumentoCertsignDoc(array $params) {
        
        $sql = "SELECT IDDOCUMCERTSIGN, CHAVEDOCUMCERTSIGN 
                  FROM FCT_CONTRATODOC
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRSEQCONTDOC = :NRSEQCONTDOC
                   AND ((IDSITUACAOCONTRATO IN ('A','D'))
                    OR (IDSITUACAOCONTRATO IS NULL))
                   AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * A função "updateSituacaoAssManualDoc" atualiza o signatario como  "Assinado Manualmente"
     */
    public function updateSituacaoAssManualDoc(array $params) {
        
        $sql = "UPDATE FCT_DOCASSINATCONTR
                   SET IDSIGNATCERTSIGN = NULL,
                       IDSITUACAO = 'M',
                       DTULTATU = SYSDATE, 
                       CDOPERULTATU = :OPERADOR, 
                       NRORGULTATU = :NRORG
                 WHERE NRASSDIGITALCONTR = :NRASSDIGITALCONTR
                   AND NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRSEQCONTDOC = :NRSEQCONTDOC
                   AND IDSITUACAO = 'P'
                   AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * A função "getCpfSignatAssDoc" recebe o CPF dos signatários dos documentos do Certsign
     */
    public function getCpfSignatAssDoc(array $params) {
        
        $sql = "SELECT NRCPFSIGNATARIO 
                  FROM FCT_ASSINATDIGITALCONTR
                 WHERE NRASSDIGITALCONTR = :NRASSDIGITALCONTR
                   AND NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    
    /* Recebe situação e justificativa de recusa dos documentos de assinatura do contrato */
    public function recebeDadosAssDocContr (array $params){
    
        $sql = "SELECT IDSITUACAO, DSJUSTIFICARECUSA
                  FROM FCT_DOCASSINATCONTR
                 WHERE NRASSDIGITALCONTR = :NRASSDIGITALCONTR
                   AND NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    
    /*Atualiza situação das assinaturas do contrato*/
    public function updateAssinaContrato (array $params) {
        $sql = "UPDATE FCT_ASSINATDIGITALCONTR
                   SET IDSITUACAO = :IDSITUACAO,
                       DSJUSTIFICARECUSA = :DSJUSTIFICARECUSA,
                       DTULTATU = SYSDATE,
                       CDOPERULTATU = :OPERADOR, 
                       NRORGULTATU = :NRORG
                 WHERE NRASSDIGITALCONTR = :NRASSDIGITALCONTR
                   AND NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);

    }
    
    public function recebeSeqSignatario(array $params) {
        $sql = "SELECT NRASSDIGITALCONTR 
                  FROM FCT_ASSINATDIGITALCONTR
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRCPFSIGNATARIO = :NRCPFSIGNATARIO
                   AND NRORG = :NRORG";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function recebeSeqDocContr(array $params) {
        $sql = "SELECT NRSEQCONTDOC
                  FROM FCT_CONTRATODOC
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG = :NRORG
                   AND IDSITUACAOCONTRATO = 'D'";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function insereDocAssinatura(array $params) {
        $sql = "INSERT INTO  FCT_DOCASSINATCONTR 
            		(NRDOCASSINATCONTR, NRASSDIGITALCONTR, NRSEQCONTDOC, IDSITUACAO, IDSIGNATCERTSIGN, NRSEQCONTRATO,
            		NRORG, IDATIVO, DTINCLUSAO, CDOPERINCLUSAO, NRORGINCLUSAO)
                 VALUES
                    (:NRDOCASSINATCONTR,:NRASSDIGITALCONTR,:NRSEQCONTDOC,'P',:IDSIGNATCERTSIGN, :NRSEQCONTRATO,
                    :NRORG, 'S', SYSDATE,:OPERADOR,:NRORG)";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function getParcelasOrderQtDiasFatu(array $params){
        
        $sql = "SELECT NRPARCELANEGOCONT,
                       QTDIASFATURAMENTO,
                       NRPARCELA,
                       NRDIAVENCIMENTO,
                       NRNEGOCIACAOCONTRATO,
                       VRPARCELA,
                       NRPARCELANEGOPROP,
                       NRORG,
                       NRORGINCLUSAO,
                       CDOPERINCLUSAO
                  FROM FCT_PARCELANEGOCONT
                 WHERE NRNEGOCIACAOCONTRATO = :NRNEGOCIACAOCONTRATO
                   AND NRORG = :NRORG
                 ORDER BY QTDIASFATURAMENTO";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function atualizarNrParcelas(array $params){
        
        $sql = "UPDATE FCT_PARCELANEGOCONT
                   SET NRPARCELA = :NRPARCELA
                 WHERE NRPARCELANEGOCONT = :NRPARCELANEGOCONT
                   AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /* atualizar a situação do contrato para 'Suspenso' */
    public function atualizaSituacaoSuspenso(array $params) {
        
        $sql = "UPDATE FCT_CONTRATO
                   SET IDSITUACAOCONTRATO = :IDSITUACAO,
                       DTSUSPENSAO = :DTSUSPENSAO,
                       CDOPERULTATU = :OPERADOR,
                       DTULTATU = SYSDATE,
                       NRORGULTATU = :NRORG,
                       CDOPERSOLSUSPENSAO = :CDOPERSOLSUSPENSAO,
                       DSJUSTIFCASUSPENSAO = :DSJUSTIFCASUSPENSAO
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG = :NRORG";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    
    /* Deleta as medições dsem parcela para suspensão do contrato  */
    public function DeletaMedicoesSuspensaoSemParcela(array $params) {
        
        $sql = "DELETE FROM FCT_MEDICAOFATURA
                  WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                    AND IDSITUACAO <> '4'
                    AND (((DTINICOMPET >= :DTSUSPENSAO) OR (DTFINCOMPET > :DTSUSPENSAO))
                       OR (:DTSUSPENSAO IS NULL))
                    AND NRORG = :NRORG";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    /* Deleta as medições dsem parcela para suspensão do contrato  */
    public function DeletaMedicoesSuspensaoParcela(array $params) {
        
        $sql = "DELETE FROM FCT_MEDICAOFATURA
                 WHERE NRMEDICAOFATURA IN (SELECT FCT_RELACAGRUPCONTFAT.NRMEDICAOFATURA
                                             FROM FCT_RELACAGRUPCONTFAT
                                             JOIN FCT_FATURACONT 
                                               ON FCT_FATURACONT.NRFATURACONT = FCT_RELACAGRUPCONTFAT.NRFATURACONT 
                                              AND FCT_FATURACONT.NRORG = FCT_RELACAGRUPCONTFAT.NRORG
                                            WHERE FCT_RELACAGRUPCONTFAT.NRSEQCONTRATO = :NRSEQCONTRATO
                                              AND FCT_RELACAGRUPCONTFAT.NRMEDICAOFATURA IS NOT NULL
                                              AND FCT_FATURACONT.IDSITUACAO <> 3
                                              AND (((FCT_FATURACONT.DTINICOMPET >= :DTSUSPENSAO) OR (FCT_FATURACONT.DTFINCOMPET > :DTSUSPENSAO))
                                                     OR (:DTSUSPENSAO IS NULL))
                                              AND FCT_RELACAGRUPCONTFAT.NRORG = :NRORG)
                    AND IDSITUACAO = '4'
                    AND NRORG = :NRORG";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function recebeIdUtilizaComp(array $params) {
        $sql = "SELECT COUNT(*) AS UTILIZACOMP
                  FROM FCT_TRABSERVCONTRATO 
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO 
                   AND NRORG = :NRORG";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    /**
     * Retorna o parametro validação para a geração de 
     * documentos de encerramento em Docx ou PDF
    **/
    public function getParametroExtensaoDocEncerra(array $params){
        $sql = "SELECT IDPERMITEDOCX, NRSEQMODDOCFCT 
                  FROM FCT_TIPORESCISAO 
                 WHERE NRTIPORESCISAO = :NRTIPORESCISAO
                   AND NRORG = :NRORG";
                    
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
     /* Verifica se um contrato possui alguma negociação feita para um de seus itens ou elementos.
     */
    public function verificarSeContratoPossuiNegociacao(array $params) {
        $sql = "SELECT COUNT(*) AS QTD
                  FROM (
                        SELECT NEG.NRNEGCONTRATO,
                               NEG.IDATIVO,
                               NEG.NRORG,
                               NEG.NRSEQCONTRATO,
                               MIN(PARC.DTINIPARCNEGOCIA) AS DTINI,
                               MAX(PARC.DTFIMPARCNEGOCIA) AS DTFIN
                          FROM FCT_NEGCONTRATO NEG
                         INNER JOIN FCT_PARCELASNEGCONTR PARC
                            ON NEG.NRNEGCONTRATO = PARC.NRNEGCONTRATO
                           AND NEG.NRORG         = PARC.NRORG
                         GROUP BY NEG.NRNEGCONTRATO,
                               NEG.IDATIVO,
                               NEG.NRORG,
                               NEG.NRSEQCONTRATO
                  ) NEG, FCT_CONTRATO NEWCONT
                 WHERE NEG.NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NEG.NRORG         = :NRORG
                   AND NEG.IDATIVO       = 'S'
                   AND NEWCONT.NRSEQCONTRATO = :NEWNRSEQCONTRATO
                   AND TRUNC(NEG.DTFIN) >= TRUNC(NEWCONT.DTINIVIGENCONT)";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    /**
     * Verifica se a proposta é normal ou alimentícia
     **/
    public function verificaPropostaAlimenticia(array $params) {
        
        $sql = "SELECT IDPROPALIMENTICIA
                  FROM FCT_ORCAMENTO
                 WHERE NRSEQORCAMENTO = :NRSEQORCAMENTO 
                   AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $retorno = $std->fetchAll();
        return $retorno[0]["IDPROPALIMENTICIA"];
    }
    
    /**
     * Recebe o nome do parceiro de negócio 
     **/
    public function recebeNomeParceiro(array $params) {
        
        $sql = "SELECT NMPRINCIPALPARC
                  FROM PARCNEGOCIO
                 WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO 
                   AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $retorno = $std->fetchAll();
        return $retorno[0]["NMPRINCIPALPARC"];
    }
    
    /* insere dados aprovação contrato  */
    public function insereAprovacaoContrato(array $params) {
        
        $sql = "INSERT INTO FCT_APROVACONTRATO
                    			(NRSEQAPROVCONT, NRSEQCONTRATO, DTAPROVCONTR, IDAPROCCONTR, CDINTERLOCONTR, NRCONTATOCONTR, 
                    			 CDFILCONTCONTR, DSAPROVCONTR, NRORG, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO, IDATIVO)
                    	VALUES
                    			(:NRSEQAPROVCONT, :NRSEQCONTRATO, SYSDATE, 'A', NULL, NULL, 
                    			 NULL, NULL, :NRORG, SYSDATE, :NRORG, :OPERADOR, 'S')";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    /* atualiza o contrato para colcoar a aprovação  */
    public function atualizaContratoAprovacao(array $params) {
        
        $sql = "UPDATE FCT_CONTRATO
                   SET IDSITUACAOCONTRATO = 'A',
                       DTULTATU = SYSDATE,
                       NRORGULTATU = :NRORG,
                       CDOPERULTATU = :OPERADOR
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG = :NRORG";

        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
     /**
     * Valida se é necessário filtrar os serviços na inserção de contratos manuais
    **/
    public function validaFiltroServico(array $params) {
        
        $sql = "SELECT IDFILTRASERVICO
                  FROM FCT_TIPOORCAMENTO
                 WHERE NRTIPOORCAMENTO = :NRTIPOORCAMENTO
                   AND NRORG = :NRORG";
            
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $retorno = $std->fetchAll();
        return $retorno[0]["IDFILTRASERVICO"];
    }
    
     /**
     * Valida se é necessário filtrar os serviços na inserção de contratos manuais
    **/
    public function countServicos(array $params) {
        
        $sql = "SELECT COUNT(*) AS VALIDA
                  FROM FCT_ITESCOPOPROPOSTA
                 WHERE NRTIPOORCAMENTO = :NRTIPOORCAMENTO
                   AND NRORG = :NRORG";
            
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $retorno = $std->fetchAll();
        return $retorno[0]["VALIDA"];
    }
    
    public function recebeDadosContratoVersionado(array $params) {
        
        $sql = "SELECT NRSEQCONTRATO, DSOBSERVACAOCONT
                  FROM FCT_CONTRATO 
                 WHERE NRSEQCONTRATOPAI = :NRSEQCONTRATO
                   AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Verifica se um contrato possui alguma negociação feita para um de seus itens ou elementos.
     */
    public function recebeDadosNegociacao(array $params) {
        $sql = "SELECT NRNEGOCIACAOCONTRATO, CDTIPOOPERFATURA, CDSERIENF, CDEMPRESA, CDINSCESTA, CDINSCMUNI,
                       FCT_BUSCA_DESCRICAO_ESCOPO(NRTIPOORCAMENTO, IDTPFATURA, CDFILIALFATURA, NRPARCFATURA, CDTIPOOPERFATURA, CDSERIENF, CDEMPRESA, CDINSCESTA, CDINSCMUNI, NRORG) AS DESCRICAO
                  FROM FCT_NEGOCIACAOCONTRATO
                 WHERE FCT_NEGOCIACAOCONTRATO.NRSEQCONTRATO = :NRSEQCONTRATO
                   AND FCT_NEGOCIACAOCONTRATO.IDTPFATURA = 'P'
                   AND FCT_NEGOCIACAOCONTRATO.NRORG = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function recebeValorFaturado(array $params) {
        
        $sql = "SELECT NVL(SUM(FCT_FATURACONT.VRFATURADO),0) AS VRFATURADO  
                  FROM FCT_FATURACONT 
                  JOIN FCT_RELACAGRUPCONTFAT
                    ON FCT_RELACAGRUPCONTFAT.NRFATURACONT = FCT_FATURACONT.NRFATURACONT
                   AND FCT_RELACAGRUPCONTFAT.NRORG = FCT_FATURACONT.NRORG
                 WHERE FCT_RELACAGRUPCONTFAT.NRSEQCONTRATO = :NRSEQCONTRATO
                   AND FCT_FATURACONT.IDTPFATURA = 'P'
                   AND FCT_FATURACONT.IDSITUACAO IN ('2', '3')
                   AND FCT_FATURACONT.CDTIPOOPERFATURA = :CDTIPOOPERFATURA
                   AND FCT_FATURACONT.CDSERIENF = :CDSERIENF
                   AND FCT_FATURACONT.CDEMPRESA = :CDEMPRESA
                   AND FCT_FATURACONT.CDINSCESTA = :CDINSCESTA
                   AND FCT_FATURACONT.CDINSCMUNI = :CDINSCMUNI
                   AND FCT_FATURACONT.NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $retorno = $std->fetchAll();
        return $retorno[0]["VRFATURADO"];
    }
    
    public function recebeNegociacaoParcelas(array $params) {
        
        $sql = "SELECT NRNEGOCIACAOCONTRATO
                  FROM FCT_NEGOCIACAOCONTRATO
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND CDTIPOOPERFATURA = :CDTIPOOPERFATURA
                   AND CDSERIENF = :CDSERIENF
                   AND CDEMPRESA = :CDEMPRESA
                   AND CDINSCESTA = :CDINSCESTA
                   AND CDINSCMUNI = :CDINSCMUNI
                   AND NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $retorno = $std->fetchAll();
        return $retorno[0]["NRNEGOCIACAOCONTRATO"];
    }
    
    public function deleteParcelasParamNegociacao(array $params) {
        $sql = "DELETE FROM FCT_PARCELANEGOCONT
                 WHERE NRNEGOCIACAOCONTRATO = :NRNEGOCIACAOCONTRATO
                   AND NRORG = :NRORG";
                    
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);

    }
    
    public function atualizaObsContratoVers(array $params) {
        $sql = "UPDATE FCT_CONTRATO
                   SET DSOBSERVACAOCONT = :DSOBSERVACAOCONT
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG = :NRORG";
                    
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);

    }
    
    /**
     * Pegar os dados da tabela FCT_CONTRATOREAJUSTE
     * @param $params = ["NRORG","NRSEQCONTRATO"] 
     * @return  array[LINHAS][COLUNAS DA TABELA]
     */
    public function getDadosReajusteContrato(array $params){
      $sql="SELECT * 
              FROM (
                SELECT C.NRORG, C.NRULTIMOREAJUSTE, C.NRSEQPRORRCONT, C.NRCONTREAJUSTE, C.NRSEQCONTRATO
                  FROM FCT_CONTRATOREAJUSTE C
                 WHERE C.NRORG = :NRORG
                   AND C.NRSEQCONTRATO = :NRSEQCONTRATO
                   AND C.NRULTIMOREAJUSTE IS NOT NULL
                 ORDER BY C.NRULTIMOREAJUSTE DESC, C.NRCONTREAJUSTE DESC)
             WHERE ROWNUM = 1";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    
    /**
     * Excluir os dados da tabela FCT_ITNEGOCIACAOACONTRATO_HR
     * @param $params = ["NRORG","NRITNEGOCIACAO_HR"] 
     * @return  array[LINHAS][COLUNAS DA TABELA]
     */
    public function excluiItensNegociacoHistorico(array $params){
      $sql="DELETE 
            FROM FCT_ITNEGOCIACAOCONTRATO_HR hr
            WHERE hr.NRULTIMOREAJUSTE = :NRULTIMOREAJUSTE
            AND hr.NRORG = :NRORG"; 
      $std = $this->connection->prepare($sql);
      $std->execute($params);
    }
    
   /**
     * Excluir os dados da tabela FCT_PARCELANEGOCONT_HR
     * @param $params = ["NRORG","NRPARCELANEGOCONT_HR"] 
     * @return  array[LINHAS][COLUNAS DA TABELA]
     */
    public function excluiParcelasNegociacoHistorico(array $params){
      $sql="DELETE 
          FROM FCT_PARCELANEGOCONT_HR hr
            WHERE hr.NRULTIMOREAJUSTE = :NRULTIMOREAJUSTE
          AND hr.NRORG = :NRORG"; 
      $std = $this->connection->prepare($sql);
      $std->execute($params);
    }
    
    /**
     * Excluir os dados da tabela FCT_NEGOCIACAOCONTRATO_HR
     * @param $params = ["NRORG","NRNEGOCIACAOCONTRATO_HR"] 
     * @return  array[LINHAS][COLUNAS DA TABELA]
     */
    public function excluiNegociacaoContrato(array $params){
      $sql="DELETE 
          FROM FCT_NEGOCIACAOCONTRATO_HR hr
            WHERE hr.NRULTIMOREAJUSTE = :NRULTIMOREAJUSTE
          AND hr.nrorg = :NRORG"; 
      $std = $this->connection->prepare($sql);
      $std->execute($params);
    }
    
    /**
     * Excluir os dados da tabela FCT_ITEMCONTRATO_HR
     * @param $params = ["NRORG","NRITEMOCONTRATO_HR"] 
     * @return  array[LINHAS][COLUNAS DA TABELA]
     */
    public function excluiItemContratoHistorico(array $params){
      $sql="DELETE 
            FROM FCT_ITEMCONTRATO_HR hr
            WHERE hr.NRULTIMOREAJUSTE = :NRULTIMOREAJUSTE
            AND hr.NRORG = :NRORG"; 
      $std = $this->connection->prepare($sql);
      $std->execute($params);
    }
    
    
    /**
     * Pegar os dados da tabela FCT_ITNEGOCIACAOACONTRATO_HR
     * @param array $params = ["NRORG","NRITEMOCONTRATO"] 
     * @return  array[LINHAS][COLUNAS DA TABELA]
     */
    public function getItensNegociacaoHistorico(array $params){
        $sql="SELECT hr.IDATIVO,hr.IDTPDESCONTO,hr.NRITEMCONTRATOPAI,hr.NRITEMOCONTRATO,hr.NRITNEGOCIACAOCONTRATO,hr.NRITNEGOCIACAOCONTRATO_HR,hr.NRNEGOCIACAOCONTRATO,hr.NRORG,hr.VRDESCITEM,hr.VRPERCDESCITEM,hr.VRTOTITEM,hr.VRTOTITEMCOMDESC, hr.NRULTIMOREAJUSTE
                FROM FCT_ITNEGOCIACAOCONTRATO_HR hr
                WHERE hr.NRULTIMOREAJUSTE = :NRULTIMOREAJUSTE
                AND hr.NRORG = :NRORG"; 
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /**
     * Pegar os dados da tabela FCT_PARCELANEGOCONT_HR
     * @param array $params = ["NRORG","NRITEMOCONTRATO"] 
     * @return  array[LINHAS][COLUNAS DA TABELA]
     */
    public function getParcelasNegociacoHistorico(array $params){
      $sql="SELECT hr.IDATIVO,hr.NRNEGOCIACAOCONTRATO,hr.NRPARCELA,hr.NRPARCELANEGOCONT, hr.NRPARCELANEGOCONT_HR,hr.VRPARCELA, hr.NRULTIMOREAJUSTE
          FROM FCT_PARCELANEGOCONT_HR hr
          WHERE hr.NRULTIMOREAJUSTE = :NRULTIMOREAJUSTE
          AND hr.NRORG = :NRORG"; 
      $std = $this->connection->prepare($sql);
      $std->execute($params);
      return $std->fetchAll();
    }
    
    public function getDatasProrrogContrato(array $params){
      $sql="SELECT pc.DTANTDTINICIAL, pc.DTANTDTFINAL
          FROM FCT_PRORROGCONTRATO pc
          WHERE pc.DTANTDTINICIAL IS NOT NULL 
          AND pc.DTANTDTFINAL IS NOT NULL 
          AND pc.NRSEQPRORRCONT = :NRSEQPRORRCONT
          AND pc.NRORG = :NRORG"; 
      $std = $this->connection->prepare($sql);
      $std->execute($params);
      return $std->fetchAll();
    }
    
    /**
     * Pegar os dados da tabela FCT_NEGOCIACAOCONTRATO_HR
     * @param array $params = ["NRORG","NRITEMOCONTRATO"] 
     * @return  array[LINHAS][COLUNAS DA TABELA]
     */
    public function getNegociacaoContrato(array $params){
      $sql="SELECT hr.IDATIVO,hr.IDTPDESCONTO,hr.NRNEGOCIACAOCONTRATO,hr.NRNEGOCIACAOCONTRATO_HR,hr.NRORG,hr.NRORGINCLUSAO,hr.VRDESCITEM,hr.VRPERCDESCITEM,hr.VRTOTITEM,hr.VRTOTITEMCOMDESC, hr.NRULTIMOREAJUSTE
          FROM FCT_NEGOCIACAOCONTRATO_HR hr
          WHERE hr.NRULTIMOREAJUSTE = :NRULTIMOREAJUSTE
          AND hr.nrorg = :NRORG"; 
      $std = $this->connection->prepare($sql);
      $std->execute($params);
      return $std->fetchAll();
    }
    /**
     * Pegar os dados da tabela FCT_ITEMCONTRATO_HR
     * @param array $params = ["NRORG","NRITEMOCONTRATO"] 
     * @return  array[LINHAS][COLUNAS DA TABELA]
     */
    public function getItemContratoHistorico(array $params){
      $sql="SELECT hr.IDATIVO, hr.IDMULTMEDVRTOT, hr.NRITEMCONTRATO_HR, hr.NRITEMOCONTRATO, hr.NRORG, hr.NRORGINCLUSAO, hr.NRORGULTATU, hr.QTITEMCONTRATO,
      hr.QTMEDIDACALCULADA, hr.QTMEDIDACONTR, hr.VRTOTITEMCONT, hr.VRUNITITEMCONT,
      hr.VRUNITITEMCONTTBLPRECO , hr.NRULTIMOREAJUSTE
      FROM FCT_ITEMCONTRATO_HR hr
            WHERE hr.NRULTIMOREAJUSTE = :NRULTIMOREAJUSTE
            AND hr.NRORG = :NRORG"; 
      $std = $this->connection->prepare($sql);
      $std->execute($params);
      return $std->fetchAll();
    }
    
    
	public function atualizarRenovacaoContrato(array $params) {
		$sql = "UPDATE FCT_CONTRATO
				SET DTINIVIGENCONT	= :DTINICIO,
				DTFINVIGENCONT	= :DTFIM
				WHERE NRSEQCONTRATO = :NRSEQCONTRATO
				AND NRORG         = :NRORG";
		$std = $this->connection->prepare($sql);
		$std->execute($params);
    }
    
    public function excluiUltimoReajusteContratoReajuste(array $params){
		$sql = "DELETE
		        FROM FCT_CONTRATOREAJUSTE 
            WHERE NRULTIMOREAJUSTE = :NRULTIMOREAJUSTE
				    AND NRORG = :NRORG";
		$std = $this->connection->prepare($sql);
		$std->execute($params);
    }

	public function atualizarItemContratoHistorico(array $params) {
		$sql = "UPDATE FCT_ITEMCONTRATO
				SET IDATIVO   = :IDATIVO   ,
					IDMULTMEDVRTOT  = :IDMULTMEDVRTOT  ,
					QTITEMCONTRATO = :QTITEMCONTRATO,
					QTMEDIDACALCULADA = :QTMEDIDACALCULADA,
					QTMEDIDACONTR = :QTMEDIDACONTR,
					VRTOTITEMCONT = :VRTOTITEMCONT,
					VRUNITITEMCONT = :VRUNITITEMCONT,
					VRUNITITEMCONTTBLPRECO = :VRUNITITEMCONTTBLPRECO
				WHERE NRITEMOCONTRATO = :NRITEMOCONTRATO
				AND NRORG         = :NRORG";
		$std = $this->connection->prepare($sql);
		$std->execute($params);
    }

	public function atualizarItensNegociacaoContratoHistorico(array $params) {
		$sql = "UPDATE FCT_ITNEGOCIACAOCONTRATO
				SET IDATIVO = :IDATIVO,
					IDTPDESCONTO = :IDTPDESCONTO,
					VRDESCITEM = :VRDESCITEM,
					VRPERCDESCITEM = :VRPERCDESCITEM,
					VRTOTITEM = :VRTOTITEM,
					VRTOTITEMCOMDESC = :VRTOTITEMCOMDESC
				WHERE  NRITNEGOCIACAOCONTRATO = :NRITNEGOCIACAOCONTRATO
				AND NRORG         = :NRORG";
					
		$std = $this->connection->prepare($sql);
		$std->execute($params);
    }

	public function atualizarNegociacaoContratoHistorico(array $params) {
		$sql = "UPDATE FCT_NEGOCIACAOCONTRATO
				SET IDATIVO = :IDATIVO,
				IDTPDESCONTO = :IDTPDESCONTO,
				VRDESCITEM = :VRDESCITEM,
				VRPERCDESCITEM = :VRPERCDESCITEM,
				VRTOTITEM = :VRTOTITEM,
				VRTOTITEMCOMDESC = :VRTOTITEMCOMDESC
				WHERE NRNEGOCIACAOCONTRATO = :NRNEGOCIACAOCONTRATO
				AND NRORG = :NRORG";
		$std = $this->connection->prepare($sql);
		$std->execute($params);
    }

	public function atualizarParcelaNegociacaoContratoHistorico(array $params) {
		$sql = "UPDATE FCT_PARCELANEGOCONT
				SET IDATIVO = :IDATIVO,
				NRPARCELA = :NRPARCELA,
				VRPARCELA = :VRPARCELA
				WHERE NRPARCELANEGOCONT = :NRPARCELANEGOCONT 
				AND NRORG         = :NRORG";
					
		$std = $this->connection->prepare($sql);
		$std->execute($params);
    }

    public function getDocumentosContratosRescindidos (array $params){
        $sql = "SELECT FCT_MODELODOC.NRSEQMODDOCFCT, FCT_MODELODOC.DSMODELODOCORCA, FCT_TIPORESCISAO.NRTIPORESCISAO, FCT_TIPORESCISAO.DSTIPORESCISAO, 
                       FCT_MODELODOC.NRTIPOMODELODOCUMENTO, FCT_MODELODOC.NMARQUIVO, FCT_MODELODOC.DSCAMINHOARQ, FCT_MODELODOC.DSTIPO, 
                       FCT_MODELODOC.VRTAMANHO
                  FROM FCT_MODELODOC
                  JOIN FCT_TIPORESCISAO
                    ON FCT_TIPORESCISAO.NRSEQMODDOCFCT = FCT_MODELODOC.NRSEQMODDOCFCT
                   AND FCT_TIPORESCISAO.NRORG = FCT_MODELODOC.NRORG
                 WHERE FCT_TIPORESCISAO.NRTIPORESCISAO = :NRTIPORESCISAO
                   AND FCT_TIPORESCISAO.NRORG = :NRORG";
                    
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }


    public function SaveAnexoDocContratoRescindido (array $params){
        $sql = "INSERT INTO FCT_ANEXOCONTRATO
                		(NRANEXOCONTRATO, NRSEQCONTRATO, NMARQUIVO, DSCAMINHO, DSTIPO, VRTAMANHO, 
                		 NRORG, IDATIVO, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO)
                VALUES
                		(:NRANEXOCONTRATO, :NRSEQCONTRATO, :NMARQUIVO, :DSCAMINHO, :DSTIPO, :VRTAMANHO, 
                		 :NRORG, 'S', SYSDATE, :NRORG, :OPERADOR)";
                    
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function atualizarDadosRescisaoContrato(array $params) {
        $sql = "UPDATE FCT_CONTRATO
                   SET DTPEDRESCISAOCONTR = :DTPEDRESCISAOCONTR,
                       DTRECISAOCONTR     = :DTRECISAOCONTR,
                       NRMOTIVORESCISAO   = :NRMOTIVORESCISAO,
                       NRTIPORESCISAO     = :NRTIPORESCISAO,
                       VRPENDENCIAFIN     = :VRPENDENCIAFIN,
                       DSJUSTIFICAENCERRA = :DSJUSTIFICAENCERRA,
                       DTULTATU           = SYSDATE,
                       NRORGULTATU        = :NRORG,
                       CDOPERULTATU       = :OPERADOR
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG         = :NRORG";
                    
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    
    public function validaContratosAtivos (array $params){
        
        $sql = "SELECT COUNT(*) AS VALIDA 
                  FROM FCT_CONTRATO 
                 WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO
                   AND IDSITUACAOCONTRATO <> 'E'
                   AND NRORG = :NRORG";
                    
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $retorno = $std->fetchAll();
        return $retorno[0]["VALIDA"];
    }
    
    
    public function getParcNegocioContrato (array $params){
        
        $sql = "SELECT NRPARCNEGOCIO
                  FROM FCT_CONTRATO 
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG = :NRORG";
                               
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $retorno = $std->fetchAll();
        return $retorno[0]["NRPARCNEGOCIO"];
    }
    
    
    public function updateInativaParcnegocio (array $params){
        
        $sql = "UPDATE PARCNEGOCIO
                   SET IDATIVO = 'N',
                       NRORGULTATU = :NRORG,
                       DTULTATU  = SYSDATE,
                       CDOPERULTATU = :OPERADOR
                 WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO
                   AND NRORG = :NRORG";
                                    
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }   
    

    public function updateInativaCliente (array $params){
        
        $sql = "UPDATE CLIENTE
                   SET IDATIVO = 'N',
                       IDCLIEATIV = 'N',
                       NRORGULTATU = :NRORG,
                       DTULTATU  = SYSDATE,
                       CDOPERULTATU = :OPERADOR
                 WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO
                   AND NRORG = :NRORG";
                                    
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }    
   
    public function updateInativaParceriaCliente (array $params){
        
        $sql = "UPDATE PARCERIA
                   SET IDATIVO = 'N',
                       NRORGULTATU = :NRORG,
                       DTULTATU  = SYSDATE,
                       CDOPERULTATU = :OPERADOR
                 WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO
                   AND CDTIPOPARCEIRO = 'CLIENTE'
                   AND NRORG = :NRORG";
                                    
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    } 
    
    public function insereLogDadosSuspensao (array $params){
        
        $sql = "INSERT INTO FCT_DADOSSUSPCONTR (
                    NRDADOSSUSPCONTR, NRSEQCONTRATO, DTSUSPENSAO, CDOPERSOLSUSPENSAO, DSJUSTIFCASUSPENSAO,
                    NRORG, DTINCLUSAO, CDOPERINCLUSAO, NRORGINCLUSAO, DTULTATU, CDOPERULTATU,
                    NRORGULTATU
                ) VALUES (
                    :NRDADOSSUSPCONTR, :NRSEQCONTRATO, NVL(:DTSUSPENSAO, SYSDATE), NVL(:CDOPERSOLSUSPENSAO, :OPERADOR), NVL(:DSJUSTIFCASUSPENSAO, 'Cancelamento da Suspensão do Contrato'),
                    :NRORG, SYSDATE, :OPERADOR, :NRORG, SYSDATE, :OPERADOR,
                    :NRORG
                )";
                                    
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    } 
    
    /**
     * deleta os operadores de notificação de assinatura
    **/
    public function deletaOperadoresNotifica (array $params) {
        
        $sql = "DELETE FROM FCT_RELACOPERNOTIFASSELE
                 WHERE NRASSDIGITALCONTR = :NRASSDIGITALCONTR
                   AND NRORG = :NRORG";
                             
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * insere os operadores de notificação de assinatura
    **/
    public function insereOperadoresNotifica (array $params) {
        
        $sql = "INSERT INTO FCT_RELACOPERNOTIFASSELE
                    (NRRELOPERNOTIFASSELE, NRASSDIGITALCONTR, CDOPERADOR, NRORG, IDATIVO,            
                	 DTINCLUSAO, CDOPERINCLUSAO, NRORGINCLUSAO)
                VALUES 
                    (:NRRELOPERNOTIFASSELE, :NRASSDIGITALCONTR, :CDOPERADOR, :NRORG, 'S',             
                	 SYSDATE, :OPERADOR, :NRORG)";
                             
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function recebeOrdenacaoENotificacoes(array $params) {
        $sql = "SELECT NRSIGNATPADRCONT,
                       NRORDENACAO,
                       DSEMAILNOTSIGNENV,
                       DSEMAILNOTIFOUTROS 
                  FROM FCT_SIGNATPADRMODCONT
                 WHERE NRSEQMODCONTRA = :NRSEQMODCONTRA
                   AND IDTPSIGNATARIO = :IDTPSIGNATARIO
                   AND NRORG          = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function recebeOperdoresNotificacoes(array $params) {
        $sql = "SELECT CDOPERADOR
                  FROM FCT_RELACOPERNOTIFASSELE
                 WHERE NRSIGNATPADRCONT = :NRSIGNATPADRCONT
                   AND NRORG            = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getDadosRenovacaoContrato(array $params){
        $sql = "SELECT *
                FROM (
                    SELECT FCT_PRORROGCONTRATO.NRSEQPRORRCONT, FCT_CONTRATOREAJUSTE.nrcontreajuste
                    FROM FCT_PRORROGCONTRATO
                    full outer JOIN FCT_CONTRATOREAJUSTE
                    ON FCT_PRORROGCONTRATO.NRSEQCONTRATO = FCT_CONTRATOREAJUSTE.NRSEQCONTRATO
                    WHERE FCT_PRORROGCONTRATO.NRSEQCONTRATO = :NRSEQCONTRATO
                    AND FCT_PRORROGCONTRATO.NRORG = :NRORG
                    AND DTANTDTINICIAL IS NOT NULL
                    AND DTANTDTFINAL IS NOT NULL
                    ORDER BY NRSEQPRORRCONT DESC, NRCONTREAJUSTE DESC
                )WHERE ROWNUM = 1";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getItemContratoElemento(array $params) {
        $sql = "SELECT *
                  FROM FCT_ITEMCONTRATO
                 WHERE NRSEQCONTRATO   = :NRSEQCONTRATO
                   AND NRORG           = :NRORG
                   AND CDSERVORCA      = :CDSERVORCA
                   AND CDTPMEDIDASERV  = :CDTPMEDIDASERV
                   AND IDELEMENTO      = :IDELEMENTO";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getItemContratoServico(array $params) {
        $sql = "SELECT *
                  FROM FCT_ITEMCONTRATO
                 WHERE NRSEQCONTRATO   = :NRSEQCONTRATO
                   AND NRORG           = :NRORG
                   AND CDSERVORCA      = :CDSERVORCA
                   AND CDTPMEDIDASERV  = :CDTPMEDIDASERV
                   AND IDELEMENTO      IS NULL";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getDadosRescisaoContrato(array $params) {
        $sql = "SELECT TO_CHAR(DTRECISAOCONTR, 'DD/MM/YYYY') AS DTRECISAOCONTR,
                       DSJUSTIFICAENCERRA
                  FROM FCT_CONTRATO
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG         = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }

    public function validarProdutoFaturamento(array $params) {
        $sql = "SELECT COUNT(*) AS QTD
                  FROM FCT_ITNEGOCIACAOCONTRATO IT
                  JOIN FCT_NEGOCIACAOCONTRATO NEG
                    ON IT.NRNEGOCIACAOCONTRATO = NEG.NRNEGOCIACAOCONTRATO
                 WHERE NEG.NRSEQCONTRATO = :NRSEQCONTRATO
                   AND IT.CDPRODFATURA IS NULL";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function validaBloqueiaDataInicialContReneg(array $params) {
        $sql = "SELECT IDBLOQALTDTINICONTRENEG
                  FROM FCT_MODELOCONTRATO
                 WHERE NRSEQMODCONTRA = :NRSEQMODCONTRA
                   AND NRORG = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getValoresManutencaoLicencaUsoContratoLinhaProduto(array $params) {
        $sql = "SELECT CONT.NRSEQCONTRATO,
                       TO_CHAR(CONT.DTINIVIGENCONT, 'DD/MM/YYYY') AS DTINIVIGENCONT,
                       TO_CHAR(CONT.DTFINVIGENCONT, 'DD/MM/YYYY') AS DTFINVIGENCONT,
                       CL.CDCLIENTE,
                       CL.CDLINPCLIE,
                       CL.NRPRODUTO_ID,
                       (SELECT IT.VRUNITITEMCONT
                          FROM FCT_ITEMCONTRATO IT
                         INNER JOIN FCT_SERVICOORCA SRV
                            ON IT.CDSERVORCA = SRV.CDSERVORCA
                         WHERE IT.NRSEQCONTRATO = CONT.NRSEQCONTRATO
                           AND SRV.IDLICENUSOMANUT = 'M'
                           AND IT.NRITEMCONTRATOPAI IS NOT NULL
                           AND SUBSTR(IT.IDELEMENTO, 3) = CL.NRPRODUTO_ID) AS VRMANUTENCAO,
                        (SELECT IT.VRUNITITEMCONT
                          FROM FCT_ITEMCONTRATO IT
                         INNER JOIN FCT_SERVICOORCA SRV
                            ON IT.CDSERVORCA = SRV.CDSERVORCA
                         WHERE IT.NRSEQCONTRATO = CONT.NRSEQCONTRATO
                           AND SRV.IDLICENUSOMANUT = 'L'
                           AND IT.NRITEMCONTRATOPAI IS NOT NULL
                           AND SUBSTR(IT.IDELEMENTO, 3) = CL.NRPRODUTO_ID) AS VRLICENCAUSO
                  FROM FCT_CONTRATO CONT
                 INNER JOIN CONTRATOLINP CL
                    ON CONT.NRSEQCONTRATO = CL.NRSEQCONTRATO
                 WHERE CONT.NRSEQCONTRATO = :NRSEQCONTRATO";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function updateValorLinhaProduto(array $params) {
        $sql = "UPDATE VALORLINP
                   SET VRLICENCUSOLINP = :VRLICENCUSOLINP, 
                       VRMENSALIDALINP = :VRMENSALIDALINP, 
                       NRORGULTATU     = :NRORG,
                       DTULTATU        = SYSDATE,
                       CDOPERULTATU    = :CDOPERADOR
                 WHERE CDCLIENTE           = :CDCLIENTE
                   AND CDLINPCLIE          = :CDLINPCLIE
                   AND TRUNC(DTIVIGVRLINP) = TRUNC(TO_DATE(:DTIVIGVRLINP, 'DD/MM/YYYY'))";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function getPeriodoContrato(array $params) {
        $sql = "SELECT TO_CHAR(NVL(DTINIVIGENCONT, DTINICIOCONTRATO), 'DD/MM/YYYY') AS DTINIVIGENCONT,
                       TO_CHAR(NVL(DTFINVIGENCONT, DTFIMCONTRATO), 'DD/MM/YYYY') AS DTFINVIGENCONT
                  FROM FCT_CONTRATO
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG         = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getValorlinpContratoPorData(array $params) {
        $sql = "SELECT V.CDCLIENTE,
                       V.CDLINPCLIE,
                       V.DTIVIGVRLINP,
                       V.DTFVIGVRLINP,
                       V.VRLICENCUSOLINP,
                       V.VRMENSALIDALINP
                  FROM VALORLINP V
                  JOIN CONTRATOLINP C
                    ON V.CDCLIENTE = C.CDCLIENTE
                   AND V.CDLINPCLIE = C.CDLINPCLIE
                 WHERE C.NRSEQCONTRATO = :NRSEQCONTRATO
                   AND TRUNC(V.DTIVIGVRLINP) = TRUNC(TO_DATE(:DTIVIGVRLINP, 'DD/MM/YYYY'))";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function excluirValorlinp(array $params) {
        $sql = "DELETE FROM VALORLINP
                 WHERE CDCLIENTE    = :CDCLIENTE
                   AND CDLINPCLIE   = :CDLINPCLIE
                   AND TRUNC(DTIVIGVRLINP) = TRUNC(TO_DATE(:DTIVIGVRLINP, 'DD/MM/YYYY'))";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function getTipoDocumento (array $params) {
        $sql = "SELECT NRTIPODOCCERTSIGN
                  FROM FCT_MODELOCONTRATO
                 WHERE NRSEQMODCONTRA = (SELECT NRSEQMODCONTRA
                                                FROM FCT_CONTRATO
                                            WHERE NRSEQCONTRATO = :NRSEQCONTRATO)";
                                            
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();              
    }
    
    public function getEnviarDocAss (array $params) {
        $sql = "SELECT OP.DSEMAILOPER
                  FROM FCT_CONTRATO CONT
                  JOIN OPERADOR OP
                    ON CONT.CDOPERRESPONSAVEL = OP.CDOPERADOR
                 WHERE CONT.NRSEQCONTRATO        = :NRSEQCONTRATO
                   AND IDENVIADOCOPERRESPCONCASS = 'S'";
                                            
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();              
    }
    
    public function getDadosContrato(array $params) {
        $sql = "SELECT *
                  FROM FCT_CONTRATO
                 WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                   AND NRORG         = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getDadosItemContratoParaNegociacaoValores(array $params) {
        $sql = "SELECT NEG.NRSEQCONTRATO,
                       NEG.IDTPFATURA,
                       NEG.CDFILIALFATURA,
                       NEG.NRPARCFATURA,
                       NEG.CDTIPOOPERFATURA,
                       NEG.CDSERIENF,
                       NEG.CDEMPRESA,
                       NEG.CDINSCESTA,
                       NEG.CDINSCMUNI,
                       ITNEG.NRITNEGOCIACAOCONTRATO,
                       ITNEG.VRDESCITEM,
                       ITNEG.VRPERCDESCITEM,
                       ITNEG.CDPRODFATURA,
                       CONT.NRTIPOORCAMENTO,
                       ITCONT.VRTOTITEMCONT,
                       ITCONT.CDSERVORCA
                  FROM FCT_ITNEGOCIACAOCONTRATO ITNEG
                  JOIN FCT_NEGOCIACAOCONTRATO NEG
                    ON ITNEG.NRNEGOCIACAOCONTRATO = NEG.NRNEGOCIACAOCONTRATO
                   AND ITNEG.NRORG                = NEG.NRORG
                  JOIN FCT_CONTRATO CONT
                    ON NEG.NRSEQCONTRATO = CONT.NRSEQCONTRATO
                   AND NEG.NRORG         = CONT.NRORG
                  JOIN FCT_ITEMCONTRATO ITCONT
                    ON ITNEG.NRITEMOCONTRATO = ITCONT.NRITEMOCONTRATO
                   AND ITNEG.NRORG           = ITCONT.NRORG
                 WHERE ITNEG.NRITEMOCONTRATO = :NRITEMOCONTRATO
                   AND ITNEG.NRORG           = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function getNegociacaoContratoPorParametrosFaturamento(array $params) {
        $sql = "SELECT NRNEGOCIACAOCONTRATO
                  FROM FCT_NEGOCIACAOCONTRATO
                 WHERE NRSEQCONTRATO         = :NRSEQCONTRATO
                   AND NRORG                 = :NRORG
                   AND NRTIPOORCAMENTO       = :NRTIPOORCAMENTO
                   AND IDTPFATURA            = :IDTPFATURA
                   AND CDFILIALFATURA        = :CDFILIALFATURA
                   AND NRPARCFATURA          = :NRPARCFATURA
                   AND CDTIPOOPERFATURA      = :CDTIPOOPERFATURA
                   AND CDSERIENF             = :CDSERIENF
                   AND CDEMPRESA             = :CDEMPRESA
                   AND CDINSCESTA            = :CDINSCESTA
                   AND CDINSCMUNI            = :CDINSCMUNI
                   AND (
                      NVL(:IDGERARATEIO, 'N') = 'N' OR
                      (:IDGERARATEIO = 'S' AND NVL(NRESTRUTURAM, -1) = NVL(:NRESTRUTURAM, -1))
                   )";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
    
    public function atualizarCodNegociacaoDoItemContrato(array $params) {
        $sql = "UPDATE FCT_ITNEGOCIACAOCONTRATO
                   SET NRNEGOCIACAOCONTRATO = :NRNEGOCIACAOCONTRATO
                 WHERE NRITNEGOCIACAOCONTRATO = :NRITNEGOCIACAOCONTRATO
                   AND NRORG                  = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
    }
    
    public function getDadosNegociacaoValoresContrato(array $params) {
        $sql = "SELECT *
                  FROM FCT_NEGOCIACAOCONTRATO
                 WHERE NRNEGOCIACAOCONTRATO = :NRNEGOCIACAOCONTRATO
                   AND NRORG                = :NRORG";
        
        $ps = $this->connection->prepare($sql);
        $ps->execute($params);
        return $ps->fetchAll();
    }
}

?>